@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: config.h,v 1.41 2006/03/26 12:50:04 gareuselesinge Exp $
+ * $Id: config.h,v 1.48 2007/06/22 11:04:07 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -14,7 +14,7 @@
 /******************************************************************************/
 
 // common
-#define VERSION 	"0.0.99"
+#define VERSION 	"0.2.5"
 #define PROGRAMNAME	"FreePOPs"
 #define PIDFILE 	"/var/run/freepopsd.pid"
 #define POP3PORT  	2000
@@ -27,7 +27,8 @@
 	#define DEFAULT_USERAGENT \
 		"Mozilla/5.0 (; U; Win32; en-US; rv:1.7.8)"\
 		" Gecko/20050518 Firefox/1.0.4"
-	//#define FREEPOPSLUA_USER_UNOFFICIAL "lua_unofficial"
+	#define FREEPOPSLUA_PATH_UPDATES "lua_updates/"
+	#define FREEPOPSLUA_PATH_UNOFFICIAL "lua_unofficial/"
 #endif
 
 // beos
@@ -37,7 +38,8 @@
 	#define DEFAULT_USERAGENT \
 		"Mozilla/5.0 (X11; U; BeOS; en-US; rv:1.7.8)"\
 		" Gecko/20050518 Firefox/1.0.4"
-	//#define FREEPOPSLUA_USER_UNOFFICIAL "lua_unofficial"
+	#define FREEPOPSLUA_PATH_UPDATES "/var/lib/freepops/lua_updates/"
+	#define FREEPOPSLUA_PATH_UNOFFICIAL "/var/lib/freepops/lua_unofficial/"
 #endif
 
 #ifdef MACOSX
@@ -46,7 +48,8 @@
 	#define DEFAULT_USERAGENT \
 		"Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; "\
 		"en-US; rv:1.7.5) Gecko/20041107 Firefox/1.0"
-	//#define FREEPOPSLUA_USER_UNOFFICIAL "lua_unofficial"
+	#define FREEPOPSLUA_PATH_UPDATES "src/lua_updates/"
+	#define FREEPOPSLUA_PATH_UNOFFICIAL "src/lua_unofficial/"
 #endif
 		
 // unix
@@ -56,8 +59,8 @@
 	#define DEFAULT_USERAGENT \
 		"Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.8)"\
 		" Gecko/20050518 Firefox/1.0.4"
-	//#define FREEPOPSLUA_USER_UNOFFICIAL "%s/.freepops/lua_unofficial"
-	
+	#define FREEPOPSLUA_PATH_UPDATES "/var/lib/freepops/lua_updates/"
+	#define FREEPOPSLUA_PATH_UNOFFICIAL "/var/lib/freepops/lua_unofficial/"
 #endif
 
 
