@@ -42,6 +42,10 @@ freepops.MODULES_MAP["tim.it"]		= {
 	name="tin.lua",
 	args={folder="INBOX"}
 }
+freepops.MODULES_MAP["atlantide.it"]		= {
+	name="tin.lua",
+	args={folder="INBOX"}
+}
 
 -- lycos
 freepops.MODULES_MAP["lycos.co.uk"]	= {name="davmail.lua"}
@@ -56,10 +60,12 @@ freepops.MODULES_MAP["jubii.dk"]	= {name="davmail.lua"}
 
 -- gmail
 freepops.MODULES_MAP["gmail.com"]	= {name="gmail.lua"}
+freepops.MODULES_MAP["googlemail.com"]	= {name="gmail.lua"}
 
 -- yahoo
 freepops.MODULES_MAP["yahoo.com"]	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.ar"]	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.ie"]       	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.it"]       	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.ca"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.co.in"] 	= {name="yahoo.lua"}
@@ -71,6 +77,7 @@ freepops.MODULES_MAP["yahoo.com.hk"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.es"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.de"]        = {name="yahoo.lua"} 
 freepops.MODULES_MAP["yahoo.dk"]        = {name="yahoo.lua"} 
+freepops.MODULES_MAP["yahoo.fr"]        = {name="yahoo.lua"} 
 freepops.MODULES_MAP["rocketmail.com"]  = {name="yahoo.lua"}
 freepops.MODULES_MAP["talk21.com"]  = {name="yahoo.lua"}
  
@@ -88,6 +95,16 @@ freepops.MODULES_MAP["charter.com"]		= {name="hotmail.lua"}
 freepops.MODULES_MAP["compaq.net"]		= {name="hotmail.lua"}
 freepops.MODULES_MAP["passport.com"]		= {name="hotmail.lua"}
 freepops.MODULES_MAP["messengeruser.com"]	= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.com"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.nl"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.be"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.ca"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.de"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.fr"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.it"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.nl"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.co.uk"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["live.com.au"]		= {name="hotmail.lua"}
 
 -- aol
 freepops.MODULES_MAP["aol.com"]		= {name="aol.lua"}
@@ -125,6 +142,7 @@ freepops.MODULES_MAP["mp4.it"]		= {name="supereva.lua"}
 freepops.MODULES_MAP["dadacasa.com"]	= {name="supereva.lua"}
 freepops.MODULES_MAP["clarence.com"]	= {name="supereva.lua"}
 freepops.MODULES_MAP["concento.it"]	= {name="supereva.lua"}
+freepops.MODULES_MAP["dada.net"]	= {name="supereva.lua"}
 
 -- mail.com
 freepops.MODULES_MAP["mail.com"]		= {name="mailcom.lua"}
@@ -155,6 +173,7 @@ freepops.MODULES_MAP["mad.scientist.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["playful.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["poetic.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["popstar.com"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["popstarmail.org"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["saintly.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["seductive.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["soon.com"]		= {name="mailcom.lua"}
@@ -426,6 +445,7 @@ freepops.MODULES_MAP["mail.org" ]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["italymail.com" ]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["computer4u.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["mexico.com"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["india.com"]		= {name="mailcom.lua"}
 
 -- mail2world
 freepops.MODULES_MAP["mail2.*%.com" ]		= {name="mail2world.lua", 
@@ -656,6 +676,10 @@ freepops.MODULES_MAP["linuxgazette.net"] 	= {
 	args={host="http://linuxgazette.net/lg.rss"}
 }
 
+-- Updater
+--
+freepops.MODULES_MAP["updater"] = {name="updater.lua"}
+
 -- -------------------------------------------------------------------------- --
 -- 2) Policy
 --
@@ -704,18 +728,25 @@ freepops.REJECTED_ADDRESSES = {
 freepops.MODULES_PREFIX = {
 	-- Culd this be a security hole? this VAR is set by FP, but ...
 	-- ... I need to read more about environment ...
+	os.getenv("FREEPOPSLUA_PATH_UPDATES") or "./",
 	os.getenv("FREEPOPSLUA_PATH") or "./",
 	"./lua/",
 	"./",
 	"./src/lua/",
 	"./modules/include/",
 	"./modules/lib/"}
+
+freepops.MODULES_CPREFIX = {
+	os.getenv("FREEPOPSLUA_CPATH") or "./",
+	"./c/",
+	"./",
+	"./updater-ui/fltk/" }
 	
 -- Really interesting for the geek user.
 -- These paths are searched for unofficial plugins
 freepops.MODULES_PREFIX_UNOFFICIAL = {
 	os.getenv("FREEPOPSLUA_PATH_UNOFFICIAL") or "./",
-	"./src/lua_unofficial",
+	"./src/lua_unofficial/",
 	--os.getenv("FREEPOPSLUA_USER_UNOFFICIAL") or "./"
 	}
 
