@@ -59,6 +59,13 @@
 -- <B>ssl_init_stuff()</B> : some stuff for SSL<BR/>
 --<BR/>
 
+MODULE_VERSION = "0.1.0"
+MODULE_NAME = "browser.browser"
+MODULE_REQUIRE_VERSION = "0.2.0"
+MODULE_LICENSE = "GNU/GPL"
+MODULE_URL = "http://www.freepops.org/download.php?module=browser.browser.lua"
+MODULE_HOMEPAGE = "http://www.freepops.org/"
+
 require("curl")
 local cookie = require("browser.cookie")
 
@@ -121,7 +128,7 @@ end
 function Hidden.find_in_header(t,s)
 	local capture = "^("..s..")"
 	return table.foreachi(t,function (k,v) 
-		local _,_,x = string.find(v,capture)
+		local x = string.match(v,capture)
 		if x ~= nil then
 			return v
 		end
@@ -146,9 +153,11 @@ function Hidden.build_header(self,url,exhed)
 			table.insert(head,"Referer: "..self.referrer)
 		end
 	end
-	if cook ~= nil then
-		table.insert(head,"Cookie: "..cook)
-	end
+        if cook ~= nil then
+           -- the excite website adds "\r\n" to the cookies...
+           if string.find(cook,"\r\n$") then cook =string.sub(cook,1,-3) end
+           table.insert(head,"Cookie: "..cook)
+        end
 	if u.host ~= nil then
 		-- This is a terrible hack.  I had to put it so that hotmail would work.  The
 		-- grammar that hotmail uses differs from the one described in cookie.lua.
@@ -172,7 +181,7 @@ function Hidden.cookie_and_referer(self,url,gl_h)
 	self.referrer = url
 
 	table.foreach(gl_h,function(_,l)
-		local _,_,content = string.find(l,
+		local content = string.match(l,
 			"^[Ss][Ee][Tt]%-[Cc][Oo][Oo][Kk][Ii][Ee]%s*:%s*(.*)")
 		if content ~= nil then
 			local c = cookie.parse_cookies(content,u.host)
@@ -230,7 +239,7 @@ end
 -- gets the field Location: in a header table
 function Hidden.get_location(gl_h,url)
 	return table.foreach(gl_h,function(_,l)
-		local _,_,location = string.find(l,
+		local location = string.match(l,
 			"[Ll][Oo][Cc][Aa][Tt][Ii][Oo][Nn]%s*:%s*([^\r\n]*)")
 		if location ~= nil then
 			-- ah ah ah, what do you think? the RFC says that
@@ -263,7 +272,7 @@ end
 -- gets the field Refresh:'s URL in a header table
 function Hidden.get_refresh_location(gl_h)
 	return table.foreach(gl_h,function(_,l)
-		local _,_,location = string.find(l,
+		local location = string.match(l,
 			"[Rr][Ee][Ff][Rr][Ee][Ss][Hh]%s*:%s*[%d]+;[Uu][Rr][Ll]=([^\r\n]*)")
 		return location
 	end)
@@ -296,12 +305,31 @@ function Hidden.parse_header(self,gl_h,url)
 	if gl_h[1] == nil then
 		return Hidden.error("malformed HTTP header line: nil")
 	end
-	local _,_,ret = string.find(gl_h[1],"[^%s]+%s+(%d%d%d)")
+	local ret = string.match(gl_h[1],"[^%s]+%s+(%d%d%d)")
 	if ret == nil then
 		--print("STRANGE HEADER!")
 		table.foreach(gl_h,print)
 		return Hidden.error("malformed HTTP header line: "..gl_h[1])
 	end
+        -- HTTP 1xx or HTTPS proxy tunnel
+        if string.byte(ret,1) == string.byte("1",1) or
+                Hidden.is_https_proxy_tunnel(self, url, ret) then
+                local gl_h1 = {} -- to not lose the real header
+                local end_of_1xx = false
+                for i=1,table.getn(gl_h) do
+                       if end_of_1xx then
+                             table.insert(gl_h1,gl_h[i])
+                       end
+                       if gl_h[i] == "\r\n" then
+                             end_of_1xx = true
+                       end
+                end
+                if gl_h1[1] ~= nil then
+                       return Hidden.parse_header(self,gl_h1,url)
+                --else
+                       --return Hidden.error("Malformed HTTP/1.x 1xx header")
+                end
+        end
 	-- HTTP 2xx
 	if string.byte(ret,1) == string.byte("2",1) then
 		if self.followRefreshHeader == true then
@@ -330,24 +358,6 @@ function Hidden.parse_header(self,gl_h,url)
 	-- HTTP 5xx
 	elseif string.byte(ret,1) == string.byte("5",1) then
 		return Hidden.errorcode(ret)
-	-- HTTP 1xx or HTTPS proxy tunnel
-	elseif string.byte(ret,1) == string.byte("1",1) or 
-	   Hidden.is_https_proxy_tunnel(self, url, ret) then
-		local gl_h1 = {} -- to not lose the real header
-		local end_of_1xx = false
-		for i=1,table.getn(gl_h) do
-			if end_of_1xx then
-				table.insert(gl_h1,gl_h[i])
-			end
-			if gl_h[i] == "\r\n" then
-				end_of_1xx = true
-			end
-		end
-		if gl_h1[1] ~= nil then
-			return Hidden.parse_header(self,gl_h1,url)
-		else
-			return Hidden.error("Malformed HTTP/1.x 1xx header")
-		end
 	else
 		return Hidden.error("Unsupported HTTP "..ret.." code")
 	end
@@ -437,7 +447,7 @@ function Hidden.mangle_location(self,loc)
 		local part_path = nil
 		local u = cookie.parse_url(self.referrer)
 		if u ~= nil then
-	                _,_,part_path = string.find(u.path or "/","(.*/)")
+	                part_path = string.match(u.path or "/","(.*/)")
 		end
                 loc = (part_path or "/") .. loc
 	end
@@ -455,6 +465,7 @@ end
 --<==========================================================================>--
 
 function Private.get_uri(self,url,exhed)
+	assert(url ~= nil,"get_uri can't be called on a nil uri")
 	local gl_b,gl_h = {},{}
 	
 	self.curl:setopt(curl.OPT_HTTPGET,1)
@@ -483,6 +494,7 @@ function Private.get_head_and_body(self,url,exhed)
 end
 
 function Private.custom_get_uri(self,url,custom,exhed)
+	assert(url ~= nil,"custom_get_uri can't be called on a nil uri")
 	local gl_b,gl_h = {},{}
 	
 	self.curl:setopt(curl.OPT_CUSTOMREQUEST,custom)
@@ -512,6 +524,7 @@ function Private.custom_post_uri(self,url,custom,post,exhed)
 end
 
 function Private.post_uri(self,url,post,exhed)
+	assert(url ~= nil,"post_uri can't be called on a nil uri")
 	local gl_b,gl_h = {},{}
 	
 	self.curl:setopt(curl.OPT_POST,1)
@@ -709,7 +722,7 @@ end
 
 --<==========================================================================>--
 
-module("browser")
+module("browser",package.seeall)
 
 ---
 -- Creates a new object.
@@ -748,7 +761,7 @@ end
 -- @return boolean.
 function ssl_enabled()
 	local s = curl.version()
-	local _,_,x = string.find(s,"([SsTt][SsLl][LlSs])")
+	local x = string.match(s,"([SsTt][SsLl][LlSs])")
 	return x ~= nil
 end
 
