@@ -3,7 +3,14 @@
 -- These functions need a <B>stat(pstate)</B> 
 -- that checks if it called more than once.
 
-module("common")
+MODULE_VERSION = "0.0.1"
+MODULE_NAME = "common"
+MODULE_REQUIRE_VERSION = "0.2.0"
+MODULE_LICENSE = "GNU/GPL"
+MODULE_URL = "http://www.freepops.org/download.php?module=common.lua"
+MODULE_HOMEPAGE = "http://www.freepops.org/"
+
+module("common",package.seeall)
 
 --============================================================================--
 -- This is part of FreePOPs (http://www.freepops.org) released under GNU/GPL  
