@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: crypto_lua.c,v 1.12 2006/01/13 21:46:54 gareuselesinge Exp $
+ * $Id: crypto_lua.c,v 1.15 2007/04/23 19:33:13 gareuselesinge Exp $
  * This file is part of FreePOPs (http://www.freepops.org)                    *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -16,7 +16,6 @@
 #include "lua.h"
 #include "luabind.h"
 #include "lauxlib.h"
-#include "compat-5.1.h"
 
 #include <stdlib.h>
 #define CRYPTO_ALGO_MD "crypto.ALGO_md.type"
@@ -195,7 +194,9 @@ static const struct L_Tuserdata crypto_ALGO [] = {
 // ====== SHA* =====
 #if CRYPTO_IMPLEMENTATION == CRYPTO_OPENSSL
 	#ifndef OPENSSL_NO_SHA
+	  #ifndef OPENWRT
 	  {"ALGO_sha",EVP_sha},
+	  #endif
 	  {"ALGO_sha1",EVP_sha1},
 	  {"ALGO_dss",EVP_dss},
 	  {"ALGO_dss1",EVP_dss1},
