@@ -2,33 +2,32 @@
 --  FreePOPs @aol.com webmail interface
 --  
 --  Released under the GNU/GPL license
---  Written by Russell Schwager <russells@despammed.com>
+--  Written by Russell Schwager <russell822@yahoo.com>
 -- ************************************************************************** --
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.9c"
+PLUGIN_VERSION = "0.1.0"
 PLUGIN_NAME = "aol.com"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=aol.lua"
+PLUGIN_URL = "http://freepops.sourceforge.net/download.php?module=aol.lua"
 PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager"}
-PLUGIN_AUTHORS_CONTACTS = {"russells (at) despammed (.) com"}
-PLUGIN_DOMAINS = {
-"@aol.com","@aol.com.ar","@aol.fr","@aol.com.mx","@aol.com.au","@aol.de",
-"@aol.com.pr","@aol.com.br","@jp.aol.com","@aol.com.uk","@aol.ca","@aola.com", 
-"@aim.com"} 
+PLUGIN_AUTHORS_CONTACTS = {"russell822 (at) yahoo (.) com"}
+PLUGIN_DOMAINS = { "@aol.com", "@aim.com"} 
 PLUGIN_PARAMETERS = 
 	{name="folder", description={
-		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox. Gli altri valori possibili sono: Junk, Trash, Draft, Sent.]],
-		en=[[The folder you want to interact with. Default is New (AOL)/Inbox (Netscape), other values are for AOL: Old, Sent, Saved, Spam and Deleted and Netscape: Sent, Trash, Draft.]]}
+		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox, gli altri valori possibili sono: Sent, Trash, Draft.]],
+		en=[[The folder you want to interact with. Default is Inbox, other values are: Sent, Trash, Draft.]]}
 	}
 PLUGIN_DESCRIPTIONS = {
 	it=[[
+Questo plugin permette di scaricare la posta da mailbox con dominio tipo @netscape.net. 
 Per usare questo plugin dovrete usare il vostro indirizzo email completo come 
 nome utente e la vostra vera password come password.]],
 	en=[[
+This plugin lets you download mail from @netscape.net mailboxes. 
 To use
 this plugin you have to use your full email address as the username
 and your real password as the password.]]
@@ -36,23 +35,19 @@ and your real password as the password.]]
 
 
 -- TODO
--- - User defined folder
 --
 
--- Domains supported:  aol.com, aol.com.ar, aol.fr, aol.com.mx, aol.com.au,
---                     aol.de, aol.com.pr, aol.com.br, jp.aol.com, aol.co.uk,
---                     aol.ca, aola.com, netscape.net, aim.com
-
 -- ************************************************************************** --
 --  Global Strings
 -- ************************************************************************** --
 
 local globals = {
   -- Server URL
-  -- 
-  strLoginUrlAOL = "http://my.screenname.aol.com/_cqr/login/login.psp?sitedomain=registration.aol.com&authLev=1&siteState=OrigUrl%3Dhttp%253a%252f%252fregistration%252eaol%252ecom%252fmail%253fs%255furl%253dhttp%25253a%25252f%25252fwebmail%25252eaol%25252ecom%25252f%25255fcqr%25252fLoginSuccess%25252easpx%25253fsitedomain%25253dsns%25252ewebmail%25252eaol%25252ecom%252526siteState%25253dver%2525253a1%252525252c0%25252526ld%2525253awebmail%25252eaol%25252ecom%25252526pv%2525253aAOL%25252526lc%2525253aen%25252dus%25252526ud%2525253aaol%25252ec",
-  strLoginUrlNetscape = "http://mail.netscape.com",
-
+  --
+  strLoginUrl = "http://classic.webmail.aol.com/",
+--"http://ncmail.netscape.com/_cqr/vllogin.adp",
+-- http://my.screenname.aol.com/_cqr/login/login.psp?siteId=%s&authLev=2&seamless=novl&siteState=",
+-- https://my.screenname.aol.com/_cqr/login/login.psp?mcState=initialized&seamless=novl&siteId=vatlasaol-static&siteState=OrigUrl%3dhttp%253a%252f%252fclassic.webmail.aol.com%252f_cqr%252fvllogin.adp&authLev=2
   -- Login strings
   --
   strLoginPostData = "loginId=%s&password=%s",
@@ -60,12 +55,11 @@ local globals = {
 
   -- Logout
   --
-  strLogout = "http://%s/logout.aspx",
+  strLogout = "http://my.screenname.aol.com/_cqr/logout/mcLogout.tmpl?siteId=aolcomnewprod",
 
   -- Expressions to pull out of returned HTML from Hotmail corresponding to a problem
   --
-  strRetLoginGoodLogin = 'gTargetHost = "([^"]+)"';
-  strRetLoginGoodLoginAim = 'gPreferredHost = "([^"]+)"';
+  strRetLoginGoodLogin = '(function reLocate)',
   strRetLoginSessionNotExpired = "(mail session has expired)",
   
   -- Regular expression to extract the mail server
@@ -73,8 +67,7 @@ local globals = {
   
   -- Pattern to extract the URL to go to get the login form
   --
-  strLoginWebmailRedirect = 'replace."([^"]+)"',
-  strLoginPageParamsPattern = 'goToLoginUrl.-Redir."([^"]+)"',
+  strLoginPageParamsPattern='goToLoginUrl.-Redir."([^"]+)"',
 
   -- Pattern to pull out the url's we need to go to set some cookies.
   --
@@ -84,59 +77,39 @@ local globals = {
   --
   strMsgListPrevPagePattern = '<A HREF="([^"]+)" CLASS="msglistbottomnav">Next</A>',
 
-  -- Pattern to extract the version of webmail
-  --
-  strVersionPattern = 'var VERSION[ ]?=[ ]?"([^"]+)";',
-
   -- Extract the server to post the login data to
   --
   strLoginPostUrlPattern1='[Mm][Ee][Tt][Hh][Oo][Dd]="[^"]*" [Aa][Cc][Tt][Ii][Oo][Nn]="([^"]*)"',
   strLoginPostUrlPattern2='[Tt][Yy][Pp][Ee]="[Hh][Ii][Dd][Dd][Ee][Nn]" [Nn][Aa][Mm][Ee]="([^"]*)" [Vv][Aa][Ll][Uu][Ee]="([^"]*)"',
   strLoginPostUrlPattern3='[Nn][Aa][Mm][Ee]="[^"]*" [Mm][Ee][Tt][Hh][Oo][Dd]="POST" [Aa][Cc][Tt][Ii][Oo][Nn]="([^"]*)"',
+  strLoginPostUrlPattern4=", '([^']+)'%);",
   
-  -- Extract the AOL internal id for the user
-  --
-  strUserIdPattern = "uid:([^&]+)&",
-
   -- Used by Stat to pull out the message ID and the size
   --
-  strMsgLinePattern = 'new MI%("([^"]+)",[^,]+,"[^"]+",[^,]+,([^,]+),',
+  strMsgLineIDPattern = 'NAME="msguid" VALUE="([^"]+)"',
 
   -- Defined Mailbox names - These define the names to use in the URL for the mailboxes
   --
-  strInboxAOL = "New%20Mail", 
-  strSpamAOL = "Spam",
-  strOldboxAOL = "Old%20Mail",
-  strTrashAOL = "Recently%20Deleted",
-  strSentAOL = "Sent%20Mail",
-  StrSavedAOL = "Saved%20Mail",
-
-  strInboxAim = "Inbox",
+  strInbox = "SU5CT1g=",
   
+  strTrashNetscape = "VHJhc2g=",
+  strSentNetscape = "U2VudA==",
+  strDraftNetscape = "RHJhZnQ=",
+
   strInboxPat = "([Nn]ew)",
-  strOldboxPat = "([Oo]ld)",
-  strSpamPat = "([Ss]pam)",
   strSentPat = "([Ss]ent)",
-  strDeletedPat = "([Dd]eleted)",
   strTrashPat = "([Tt]rash)",
   strDraftPat = "([Dd]raft)",
-  strSavedPat = "([Ss]aved)",
-
-  -- Base part of a custom folder name
-  --
-  strCustomFolderBase = "Saved%2F",
 
   -- Command URLS
   --
-  strCmdMsgList = "http://%s/GetMessageList.aspx?user=%s&page=%d&folder=%s&previousFolder=&stateToken=&newMailToken=&version=%s",
-  strCmdDelete = "http://%s/%s/%s/en-us/RPC/messageAction.aspx?folder=%s&action=delete&user=%s&version=%s", --&uid=X",
-  strCmdMsgView = "http://%s/%s/%s/en-us/Mail/rfc822.aspx?user=%s&folder=%s&uid=%s",
-  strCmdWelcome = "http://%s/MessageList.aspx",
+  strCmdMsgList = "http://%s/msglist.adp?folder=%s&start=1",
+  strCmdDelete = "http://%s/msglist.adp?folder=%s&start=1&cmd=deletemsgs", --&msguid=X",
+  strCmdMsgView = "http://%s/attachment/%s/%s/",
 
   -- Site IDs
   --
-  strAOLID = "atlasaol",
-  strNetscapeID = "nscpenusmail",
+  strNetscapeID = "vnscpenusmail",
 }
 
 -- ************************************************************************** --
@@ -153,9 +126,6 @@ internalState = {
   strDomain = nil,
   strMBox = nil,
   strSiteId = "",
-  strUserId = nil,
-  strVersion = "",
-  strBrand = "",
 }
 
 -- ************************************************************************** --
@@ -172,7 +142,7 @@ local EOL = "\r\n"
 
 -- The raw logging function
 --
-log = log or {} -- fast hack to make the xml generator happy
+local log = log or {}
 log.raw = function ( line, data )
   if not ENABLE_LOGRAW then
     return
@@ -214,7 +184,7 @@ end
 function hash()
   return (internalState.strUser or "") .. "~" ..
          (internalState.strDomain or "") .. "~"  ..
-         (internalState.strMBox or "") .. "~" ..
+         (internalState.strMBox or "") .. "~"  ..
 	 internalState.strPassword -- this asserts strPassword ~= nil
 end
 
@@ -236,10 +206,7 @@ function loginAOL()
   local username = internalState.strUser
   local password = curl.escape(internalState.strPassword)
   local domain = internalState.strDomain
-  local url = globals.strLoginUrlAOL  
-  if (domain == "netscape.net") then
-    url = globals.strLoginUrlNetscape
-  end
+  local url = string.format(globals.strLoginUrl, internalState.strSiteId)
   local xml = globals.strFolderQry
   local browser = internalState.browser
 	
@@ -259,6 +226,11 @@ function loginAOL()
   --
   local body, err = browser:get_uri(url)
 
+  -- We need to add a cookie.
+  --
+  --local c = cookie.parse_cookies("MC_COOKIETEST=YES; path=/", browser:wherearewe())
+  browser:add_cookie(url, "MC_COOKIETEST=YES; path=/")
+
   -- No connection
   --
   if body == nil then
@@ -269,24 +241,58 @@ function loginAOL()
   -- The login page sends us to a page that tests cookies and javascript.  We
   -- don't run javascript and thus must do the work here of pulling out the URL that
   -- the javascript would redirect too.
-  _, _, url = string.find(body, globals.strLoginPageParamsPattern)
+  url = string.match(body, globals.strLoginPageParamsPattern)
   if (url == nil) then
     log.error_print("Unable to figure out the redirect on the login page.")
     return POPSERVER_ERR_UNKNOWN
   end
   body, err = browser:get_uri(url)
 
-  -- Shouldn't happen but you never know
-  --
-  if body == nil then
-    log.error_print(globals.strLoginFailed)
-    return POPSERVER_ERR_NETWORK
-  end
-
   -- We are now at the signin page.  Let's pull out the action of the signin form and
   -- all the hidden variables.  When done, we'll post the data along with the user and password.
   -- 
-  _, _, url = string.find(body, globals.strLoginPostUrlPattern1)
+  url = string.match(body, globals.strLoginPostUrlPattern1)
+  local postdata = nil
+  local name, value  
+  for name, value in string.gfind(body, globals.strLoginPostUrlPattern2) do
+    value = string.gsub(value, "%%", "%%25")
+    if postdata ~= nil then
+      postdata = postdata .. "&" .. name .. "=" .. value
+    else
+      postdata = name .. "=" .. value 
+    end
+  end
+  postdata = postdata .. "&" .. 
+    string.format(globals.strLoginPostData, username, password)
+  url = "https://" .. browser:wherearewe() .. url
+  body, err = browser:post_uri(url, postdata)
+
+  -- We'll be redirected back to a page which redirects us to a non-ssl
+  -- page.
+  --
+  url = string.match(body, globals.strLoginPostUrlPattern4)
+  if url == nil then
+    log.error_print(globals.strLoginFailed)
+    return POPSERVER_ERR_AUTH  
+  end  
+  body, err = browser:get_uri(url)
+
+  -- This is where things get a little hokey.  AOL returns a page with three javascript
+  -- links that need to be "GET'ed" and then a form that needs to be submitted.  We don't
+  -- care at all about the results of the get's other than the cookies...YUM!.
+  for value in string.gfind(body, globals.strLoginRetUrlPattern1) do
+    local body2, err2 = browser:get_uri(value)
+    local cval = string.match(body2, 'hl0ckVal="([^"]+)"')
+    if (cval ~= nil) then
+      browser:add_cookie(value, "MC_CMP_ESKX=" .. cval .."; domain=.aol.com; path=/")
+    end
+    cval = string.match(body2, 'hckVal="([^"]+)"')
+    if (cval ~= nil) then
+      browser:add_cookie(value, "MC_CMP_ESK=" .. cval .. "; domain=.aol.com; path=/")
+    end
+  end
+
+  url = string.match(body, globals.strLoginPostUrlPattern3)
   local postdata = nil
   local name, value  
   for name, value in string.gfind(body, globals.strLoginPostUrlPattern2) do
@@ -296,46 +302,22 @@ function loginAOL()
       postdata = name .. "=" .. value 
     end
   end
-  postdata = postdata .. "&" .. 
-    string.format(globals.strLoginPostData, username, password)
-  url = "https://" .. browser:wherearewe() .. url
-
-  body, err = browser:post_uri(url, postdata)
-
-  -- This is where things get a little hokey.  AOL returns a page with three javascript
-  -- links that need to be "GET'ed" and then a form that needs to be submitted.  We don't
-  -- care at all about the results of the get's other than the cookies...YUM!.
-  for value in string.gfind(body, globals.strLoginRetUrlPattern1) do
-    local body2, err2 = browser:get_uri(value)
-    local _, _, cval = string.find(body2, 'hl0ckVal="([^"]+)"')
-    if (cval ~= nil) then
-      browser:add_cookie(value, "MC_CMP_ESKX=" .. cval .."; domain=.aol.com; path=/")
-    end
-    _, _, cval = string.find(body2, 'hckVal="([^"]+)"')
-    if (cval ~= nil) then
-      browser:add_cookie(value, "MC_CMP_ESK=" .. cval .. "; domain=.aol.com; path=/")
-    end
-  end
-
-  -- Need to redirect
-  --
-  _, _, url = string.find(body, "checkErrorAndSubmitForm%([^,]+, [^,]+, '([^']+)'")
   if url == nil then
-    log.raw(body)
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH  
+  end  
+  body, err = browser:post_uri(url, postdata)
+
+  -- Shouldn't happen but you never know
+  --
+  if body == nil then
+    log.error_print(globals.strLoginFailed)
+    return POPSERVER_ERR_AUTH
   end
-  body, err = browser:get_uri(url)
 
   -- We should be logged in now! Let's check and make sure.
   --
-  local str = nil
-  if (body ~= nil) then
-    _, _, str = string.find(body, globals.strRetLoginGoodLoginAim)
-    if str == nil then
-      _, _, str = string.find(body, globals.strRetLoginGoodLogin)
-    end
-  end
+  local str = string.match(body, globals.strRetLoginGoodLogin)
   if str == nil then
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH
@@ -343,35 +325,11 @@ function loginAOL()
   
   -- Save the mail server
   --
-  internalState.strMailServer = str
+  internalState.strMailServer = browser:wherearewe()
 
   -- DEBUG Message
   --
-  log.dbg("AOL/AIM Server: " .. internalState.strMailServer .. "\n")
-
-  -- Get UserID from cookie
-  --
-  local cookie = browser:get_cookie('Auth')
-  if cookie == nil then 
-    log.error_print("Unable to determine AOL internal user id.  The plugin needs to be updated.")
-  else
-    _, _, internalState.strUserId = string.find(cookie.value, globals.strUserIdPattern)
-    if internalState.strUserId == nil then 
-      log.error_print("Unable to determine AOL internal user id.  The plugin needs to be updated.")
-    end
-  end
-
-  -- Get the webmail version
-  --
-  url = string.format(globals.strCmdWelcome, internalState.strMailServer)
-  body, err = browser:get_uri(url)
-  _, _, str = string.find(body, globals.strVersionPattern)
-  if (str == nil) then 
-    internalState.strVersion = "_SRV_1_0_0_12281_"
-  else
-    internalState.strVersion = str
-  end
-  log.dbg("AOL webmail version: " .. internalState.strVersion)
+  log.dbg("AOL Server: " .. internalState.strMailServer .. "\n")
   
   -- Note that we have logged in successfully
   --
@@ -401,8 +359,8 @@ function downloadMsg(pstate, msg, nLines, data)
   --
   local browser = internalState.browser
   local uidl = get_mailmessage_uidl(pstate, msg)
-  local url = string.format(globals.strCmdMsgView, internalState.strMailServer, 
-    internalState.strVersion, internalState.strBrand, internalState.strUserId,
+  
+  local url = string.format(globals.strCmdMsgView, internalState.strMailServer,
     internalState.strMBox, uidl);
 
   -- Debug Message
@@ -454,7 +412,20 @@ function downloadMsg_cb(cbInfo, data)
     if (cbInfo.nLinesRequested ~= -2 and cbInfo.nLinesReceived == -1) then
       return 0, nil
     end
-  
+
+    -- Clean up the end of line and other things.  In the HTML portion of a message
+    -- AOL encodes it with quoted-printable.  Let's fix the easy stuff here.  This will
+    -- probably need to be looked at again.  I am sure it will cause issues in the non-HTML
+    -- portions of the message.
+    --
+--      body = string.gsub(body, "(Content%-Transfer%-Encoding:) quoted%-printable", "%1 7bit")
+--      body = string.gsub(body, "=\r\n", "")
+--      body = string.gsub(body, "=\n", "")
+--      body = string.gsub(body, "=\r", "")
+--      body = string.gsub(body, "=[Aa]0", "\n")
+--      body = string.gsub(body, "=20", " ")
+--      body = string.gsub(body, "=3[dD]", "=")
+
     -- Perform our "TOP" actions
     --
     if (cbInfo.nLinesRequested ~= -2) then
@@ -504,64 +475,42 @@ function user(pstate, username)
 
   -- Set the site id
   -- 
-  if domain == "aim.com" then
-    internalState.strBrand = "aim"
-  elseif domain == "netscape.net" then
-    internalState.strBrand = "nc"
-  else
-    internalState.strBrand = "aol"
-  end
+  internalState.strSiteId = globals.strNetscapeID
 
   -- Get the folder
   --
   local mbox = (freepops.MODULE_ARGS or {}).folder
   if mbox == nil then
-    if domain == "aim.com" or domain == "netscape.net" then
-      internalState.strMBox = globals.strInboxAim
-    else
-      internalState.strMBox = globals.strInboxAOL
-    end
+    internalState.strMBox = globals.strInbox
     return POPSERVER_ERR_OK
   end
 
-  local _, _, start = string.find(mbox, globals.strSpamPat)
+  start = string.match(mbox, globals.strSentPat)
   if start ~= nil then
-    internalState.strMBox = globals.strSpamAOL
+    internalState.strMBox = globals.strSentNetscape
     return POPSERVER_ERR_OK
   end
 
-  _, _, start = string.find(mbox, globals.strSentPat)
+  start = string.match(mbox, globals.strTrashPat)
   if start ~= nil then
-    if domain ~= "aim.com" and domain ~= "netscape.net" then
-      internalState.strMBox = globals.strSentAOL
-    end
+    internalState.strMBox = globals.strTrashNetscape
     return POPSERVER_ERR_OK
   end
 
-  _, _, start = string.find(mbox, globals.strDeletedPat)
+  start = string.match(mbox, globals.strDraftPat)
   if start ~= nil then
-    if domain ~= "aim.com" and domain ~= "netscape.net" then
-      internalState.strMBox = globals.strTrashAOL
-    end
+    internalState.strMBox = globals.strDraftNetscape
     return POPSERVER_ERR_OK
   end
 
-
-  _, _, start = string.find(mbox, globals.strOldboxPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strOldbox
-    return POPSERVER_ERR_OK
-  end
-
-  _, _, start = string.find(mbox, globals.strSavedPat)
-  if start ~= nil then
-    internalState.strMBox = globals.strSavedAOL
-    return POPSERVER_ERR_OK
-  end
-
-  -- It's a custom folder
+  -- TODO - set the other mailbox here and find it
+  -- when we log in.
   -- 
-  internalState.strMBox = globals.strCustomFolderBase .. mbox
+
+  -- Defaulting to the inbox
+  --
+  log.say("Unable to figure out the mailbox specified.  Defaulting to the Inbox.\n")
+  internalState.strMBox = globals.strInbox
   return POPSERVER_ERR_OK
 end
 
@@ -641,21 +590,22 @@ function quit_update(pstate)
   local cnt = get_popstate_nummesg(pstate)
   local dcnt = 0
 
-  local cmdUrl = string.format(globals.strCmdDelete, internalState.strMailServer,
-    internalState.strVersion, internalState.strBrand, 
-    internalState.strMBox, internalState.strUserId, internalState.strVersion)
+  local cmdUrl = string.format(globals.strCmdDelete, internalState.strMailServer, 
+    internalState.strMBox)
   local baseUrl = cmdUrl
 
   -- Cycle through the messages and see if we need to delete any of them
   -- 
   for i = 1, cnt do
     if get_mailmessage_flag(pstate, i, MAILMESSAGE_DELETE) then
-      cmdUrl = cmdUrl .. "&uid=" .. get_mailmessage_uidl(pstate, i) 
+      cmdUrl = cmdUrl .. "&msguid=" .. get_mailmessage_uidl(pstate, i) 
       dcnt = dcnt + 1
 
       -- Send out in a batch of 5
       --
       if math.mod(dcnt, 5) == 0 then
+        local cmdCookie = browser:get_cookie('COMMAND')
+        cmdUrl = cmdUrl .. "&cmdnum=" .. (cmdCookie.value or "")
         log.dbg("Sending Delete URL: " .. cmdUrl .. "\n")
         local body, err = browser:get_uri(cmdUrl)
         if not body or err then
@@ -673,6 +623,8 @@ function quit_update(pstate)
   -- Send whatever is left over
   --
   if dcnt > 0 and dcnt < 5 then
+    local cmdCookie = browser:get_cookie('COMMAND')
+    cmdUrl = cmdUrl .. "&cmdnum=" .. (cmdCookie.value or "")
     log.dbg("Sending Delete URL: " .. cmdUrl .. "\n")
     local body, err = browser:get_uri(cmdUrl)
     if not body or err then
@@ -682,8 +634,7 @@ function quit_update(pstate)
 
   -- Log out
   --
-  cmdUrl = string.format(globals.strLogout, internalState.strMailServer)
-  browser:get_uri(cmdUrl)
+  browser:get_uri(globals.strLogout)
 
   -- AOL acts retarded if we save the session.  We'll remove it and
   -- force the browser to log out.
@@ -710,8 +661,8 @@ function stat(pstate)
   -- 
   local browser = internalState.browser
   local nMsgs = 0
-  local cmdUrl = string.format(globals.strCmdMsgList, internalState.strMailServer, internalState.strUserId,
-    1, internalState.strMBox, internalState.strVersion);
+  local cmdUrl = string.format(globals.strCmdMsgList, internalState.strMailServer,
+    internalState.strMBox);
   local baseUrl = cmdUrl
 
   -- Debug Message
@@ -725,13 +676,17 @@ function stat(pstate)
   -- Local function to process the list of messages, getting id's and sizes
   --
   local function funcProcess(body)
-    -- Cycle through the items and store the msg id and size.  
-    ---
-    for uidl, size in string.gfind(body, globals.strMsgLinePattern) do
+    -- Cycle through the items and store the msg id.  AOL doesn't list the size
+    -- We'll just return the same value for every message.
+    for uidl in string.gfind(body, globals.strMsgLineIDPattern) do
+      -- Hard Code the size.
+      --
+      local size = 4096
+
       -- Save the information
       --
       nMsgs = nMsgs + 1
-      log.dbg("Processed STAT - Msg: " .. nMsgs .. ", UIDL: " .. uidl .. ", Size: " .. size)
+      log.dbg("Processed STAT - Msg: " .. nMsgs .. ", UIDL: " .. uidl .. ", (hard coded) Size: " .. size)
       set_popstate_nummesg(pstate, nMsgs)
       set_mailmessage_size(pstate, nMsgs, size)
       set_mailmessage_uidl(pstate, nMsgs, uidl)
@@ -747,7 +702,7 @@ function stat(pstate)
     -- Look in the body and see if there is a link for a previous page
     -- If so, change the URL
     --
-    local _, _, nextURL = string.find(body, globals.strMsgListPrevPagePattern)
+    local nextURL = string.match(body, globals.strMsgListPrevPagePattern)
     if nextURL ~= nil then
       cmdUrl = "http://" .. internalState.strMailServer .. "/" .. nextURL
       return false
@@ -772,7 +727,7 @@ function stat(pstate)
 
     -- Is the session expired
     --
-    local _, _, strSessExpr = string.find(body, globals.strRetLoginSessionNotExpired)
+    local strSessExpr = string.match(body, globals.strRetLoginSessionNotExpired)
     if strSessExpr ~= nil then
       -- Debug logging
       --
@@ -795,7 +750,7 @@ function stat(pstate)
       --
       browser = internalState.browser
       cmdUrl = string.format(globals.strCmdMsgList, internalState.strMailServer,
-        internalState.strMBox, internalState.strVersion)
+        internalState.strMBox)
 
       -- Retry to load the page
       --
