@@ -1,17 +1,17 @@
 -- ************************************************************************** --
 --  FreePOPs @--put here domain-- webmail interface
 -- 
---  $Id: davmail.lua,v 1.8 2006/01/26 01:39:18 russell822 Exp $
+--  $Id: davmail.lua,v 1.10 2007/01/14 16:49:36 gareuselesinge Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
 -- ************************************************************************** --
 
-PLUGIN_VERSION = "0.0.4"
+PLUGIN_VERSION = "0.0.5"
 PLUGIN_NAME = "DAVMAIL"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=owa.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=owa.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Enrico Tassi"}
 PLUGIN_AUTHORS_CONTACTS = {"gareuselesinge (at) users (.) sourceforge (.) net"}
