@@ -2,19 +2,19 @@
 --  FreePOPs @netzero/juno webmail interface
 --  
 --  Released under the GNU/GPL license
---  Written by Russell Schwager <russells@despammed.com>
+--  Written by Russell Schwager <russell822@yahoo.com>
 -- ************************************************************************** --
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.9b"
+PLUGIN_VERSION = "0.0.9k"
 PLUGIN_NAME = "juno.com"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=juno.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=juno.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager"}
-PLUGIN_AUTHORS_CONTACTS = {"russells@despammed.com"}
+PLUGIN_AUTHORS_CONTACTS = {"russell822@yahoo.com"}
 PLUGIN_DOMAINS = {"@netzero.net","@netzero.com", "@juno.com"}
 PLUGIN_PARAMETERS = {
 	{name = "folder", description = {
@@ -61,7 +61,7 @@ local globals = {
   -- Expressions to pull out of returned HTML from Yahoo corresponding to a problem
   --
   strRetLoginBadPassword = "(Sign in to Email on the Web)",
-  strRetLoginSessionExpired = "(SessionTimedOut.html)",
+  strRetLoginSessionExpired = '(var tofield = document.ComposeForm.To.value.length;)',
 
   -- Regular expression to extract the mail server
   --
@@ -71,9 +71,13 @@ local globals = {
   strLoginPostUrlPattern1='form action="([^"]*)"',
   strLoginPostUrlPattern2='name="([^"]*)" value="([^"]*)"',
 
+  -- Extract the redirect url
+  --
+  strRedirectUrl = "window%.location%.replace%('([^']+)'%)",
+
   -- Extract the mail server
   --
-  strMailServerPattern = '/([567].*)$',
+  strMailServerPattern = '/(new/[567].*)$',
 
   -- Pattern to determine if we have no messages
   --
@@ -83,7 +87,8 @@ local globals = {
   --
   --strMsgListPat = 'var msgnum = "([^"]+)";.-&nbsp;&nbsp;&nbsp;[^&]+&nbsp;.-&nbsp;&nbsp;&nbsp;([^K]+)K&nbsp;',
   strMsgListPat = 'msgNum=([^&]+)&block=.-&nbsp;&nbsp;&nbsp;[^&]+&nbsp;.-&nbsp;&nbsp;&nbsp;([^K]+)K&nbsp;',
-
+  --strMsgListPat = "%[ '([^']+)' , '[^']+' , '[^']+' , '[^']+' , '([^']+)' , '[^']+' , '[^']*' , '[^']+' , '[^']+' , '[^']+' , '[^']+' , '[^']+' , '[^']*'%]",
+                    
   -- Attachment patterns
   --
   strAttachLitPattern = ".*<table>.*<tr>.*<td>.*<img>.*</td>.*<td>.*<a>.*</a>.*</td>.*</tr>.*</table>",
@@ -93,6 +98,11 @@ local globals = {
   --
   strMsgListNextPagePattern = '(>Next%([%d]+%)</a>)',
 
+  -- The amount of time that the session should time out at.
+  -- This is expressed in seconds
+  --
+  nSessionTimeout = 14400,  -- 4 hours!
+
   -- Defined Mailbox names - These define the names to use in the URL for the mailboxes
   --
   strInbox = "Inbox",
@@ -108,6 +118,7 @@ local globals = {
   strCmdDelete = "%s/7?folder=%s&command=delete&msgList=", 
   strCmdReadOptions = "%s/48",
   strCmdEmptyTrash = "%s/6?command=Empty&folder=Trash",
+  strCmdLogout = "%s/14?type=signOut&GOTO_URL=http://my.juno.com&",
 
 }
 
@@ -127,6 +138,7 @@ internalState = {
   strMBox = nil,
   bEmptyTrash = false,
   bResetHeaders = false,
+  loginTime = nil,
 }
 
 -- ************************************************************************** --
@@ -205,14 +217,24 @@ function login()
     log.error_print("Login Failed: Unable to make connection")
     return POPSERVER_ERR_NETWORK
   end
+
   -- Check for invalid login
   -- 
-  local _, _, str = string.find(body, globals.strRetLoginBadPassword)
+  local str = string.match(body, globals.strRetLoginBadPassword)
   if str ~= nil then
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH
   end
 
+  -- Check for the redirect
+  --
+  str = string.match(body, globals.strRedirectUrl)
+  if str ~= nil then
+    body, err = browser:get_uri(str)
+  else
+    log.dbg("Unable to figure out server: " .. body)
+  end
+
   -- Extract the mail server
   --
   internalState.strMailServer = "http://" .. browser:wherearewe()
@@ -220,7 +242,7 @@ function login()
   -- The login page sometimes returns a page where a form needs to be submitted.  
   -- We'll do it manually.  Extract the form elements and post the data
   -- 
-  _, _, url = string.find(body, globals.strLoginPostUrlPattern1)
+  url = string.match(body, globals.strLoginPostUrlPattern1)
   if url ~= nil then
     url = internalState.strMailServer .. url
     local postdata = nil
@@ -236,13 +258,11 @@ function login()
 
     -- Clean up the base url
     --
-    internalState.strMailServer = string.gsub(url, 
-      globals.strMailServerPattern, "")
+    internalState.strMailServer = "http://" .. browser:wherearewe() .. "/webmail"
   else
     -- Clean up the base url
     --
-    internalState.strMailServer = string.gsub(browser:whathaveweread(), 
-      globals.strMailServerPattern, "")  
+    internalState.strMailServer = "http://" .. browser:wherearewe() .. "/webmail"
   end
 
   -- DEBUG Message
@@ -253,6 +273,10 @@ function login()
   --
   internalState.bLoginDone = true
 
+  -- Note the time when we logged in
+  --
+  internalState.loginTime = os.clock();
+
   -- Turn on full headers
   --
   url = string.format(globals.strCmdReadOptions, internalState.strMailServer)
@@ -354,7 +378,7 @@ function downloadMsg(pstate, msg, nLines, data)
 
   -- Cleanup the body if necessary
   --
-  local _, _, str = string.find(cbInfo.strBody, "^(<pre>)")
+  local str = string.match(cbInfo.strBody, "^(<pre>)")
   if str ~= nil then
     cbInfo.strBody = cleanupPreHtml(cbInfo.strBody, false)
   end
@@ -362,7 +386,7 @@ function downloadMsg(pstate, msg, nLines, data)
     
   -- Pipe this through the mimer
   --
-  --_, _, str = string.find(cbInfo.strBody, "(<[Hh][Tt][Mm][Ll]>)")
+  --str = string.match(cbInfo.strBody, "(<[Hh][Tt][Mm][Ll]>)")
   local strBody, strHtml
   if str == nil then
     strBody = nil
@@ -402,7 +426,7 @@ function downloadMsg_cb(cbInfo, data)
       -- Get rid of the text before the <pre>
       --
       if cbInfo.nMode == 0 then
-        _, _, body = string.find(body, "<pre>(.*)")
+        body = string.match(body, "<pre>(.*)")
         if body == nil or string.len(body) == 0 then
           return len, nil
         end
@@ -412,8 +436,8 @@ function downloadMsg_cb(cbInfo, data)
       -- Stop getting the headers at the </pre>
       --
       if cbInfo.nMode < 2 then
-        local _, _, str = string.find(body, "(.*)</pre>")
-        local _, _, str2 = string.find(body, "</pre>(.*)")
+        local str = string.match(body, "(.*)</pre>")
+        local str2 = string.match(body, "</pre>(.*)")
         if str ~= nil then
           body = cbInfo.strHeaders .. str
           body = processHeaders(body, cbInfo)
@@ -488,7 +512,7 @@ function processHeaders(body, cbInfo)
           
   -- Figure out if we have attachments
   --
-  local _, _, strMimeBoundary = string.find(body, '(boundary=)')
+  local strMimeBoundary = string.match(body, '(boundary=)')
   if strMimeBoundary ~= nil then
     cbInfo.bHasAttach = true
   else
@@ -497,14 +521,14 @@ function processHeaders(body, cbInfo)
   
   -- Is this a multipart-alternative message?
   --
-  local _, _, strAlternate = string.find(body, '(multipart/alternative)')
+  local strAlternate = string.match(body, '(multipart/alternative)')
   if strAlternate ~= nil then
     cbInfo.bHasAlt = true
   end
 
   -- Get the message id
   --
-  local _, _, strMessageId = string.find(body, "[Mm][Ee][Ss][Ss][Aa][Gg][Ee]%-I[dD]: <([^>]+)>")
+  local strMessageId = string.match(body, "[Mm][Ee][Ss][Ss][Aa][Gg][Ee]%-I[dD]: <([^>]+)>")
   if strMessageId ~= nil then
     cbInfo.strMessageId = strMessageId
   end
@@ -576,7 +600,7 @@ function getAttachmentTable(cbInfo, data)
   --
   for url, filename in 
     string.gfind(body,
-      [[href=['"](8%?folder=[^'"]+attachId=[0-9]+)[^'"]*['"][^>]+>.-Name = "([^"]+)"]]) 
+      [[href=['"](21%?folder=[^'"]+attachId=[0-9]+)[^'"]*['"][^>]+>.-Name = "([^"]+)"]]) 
   do
     if (filename == "Message") then
       filename = "Message.htm"
@@ -585,7 +609,7 @@ function getAttachmentTable(cbInfo, data)
     filename = getFilename(url, filename)
     log.dbg("Found Attachment, File: " .. filename .. " - Url: " .. url)
     attachments[filename] = url
-    table.setn(attachments, table.getn(attachments) + 1)
+    table.insert(attachments, table.maxn(attachments) + 1, url)
   end
   
   return attachments
@@ -600,25 +624,25 @@ function findInlineAttachments(attachments, cbInfo)
   local cnt = 0
 
   -- Find inline images and sounds
-  for url in string.gfind(body, [[[Ss][Rr][Cc]="(8[^"]+)"]]) do
+  for url in string.gfind(body, [[[Ss][Rr][Cc]="(21[^"]+)"]]) do
     attachurl = internalState.strMailServer .. "/" .. url
     filename = "juno_attach_" .. cnt .. "." .. getExtension(attachurl)
     attachId = cbInfo.strMessageId .. "." .. cnt
 
-    cbInfo.strBody = string.gsub(cbInfo.strBody, url, attachId)
+    cbInfo.strBody = string.gsub(cbInfo.strBody, string.sub(url, 4), attachId)
     log.dbg("Found inline Attachment, File: " .. filename .. " - Url: " .. url)
 
     attachments[filename] = attachurl
     inlineids[filename] = attachId
-    table.setn(attachments, table.getn(attachments) + 1)
-    table.setn(inlineids, table.getn(inlineids) + 1)
+    table.insert(attachments, table.getn(attachments) + 1, attachurl)
+    table.insert(inlineids, table.getn(inlineids) + 1, attachId)
     cnt = cnt + 1
   end
 
   -- Fixing a weird lua bug where it won't replace a string with a ? in it and
   -- add the 
   --
-  cbInfo.strBody = string.gsub(cbInfo.strBody, [[src="8.]], 'src="cid:')
+  cbInfo.strBody = string.gsub(cbInfo.strBody, [[src="21.]], 'src="cid:')
 
   return inlineids
 end
@@ -701,7 +725,7 @@ function getContentType(url)
     log.dbg(err)
     return "unknown/unknown"
   end
-  local _, _, x = string.find(h,
+  local x = string.match(h,
                 "[Cc][Oo][Nn][Tt][Ee][Nn][Tt]%-[Tt][Yy][Pp][Ee]%s*:%s*([^\r]*)")
   return (x or "unknown/unknown")
 end
@@ -718,7 +742,7 @@ function getFilename(url, filename)
     return filename
   end
 
-  local _, _, x = string.find(h, 'filename= "([^"]+)"')
+  local x = string.match(h, 'filename= "([^"]+)"')
   if (x == nil) then
     return filename
   end
@@ -905,6 +929,23 @@ function quit_update(pstate)
     local body, err = browser:post_uri(cmdUrl, postdata)
   end
 
+  -- Should we force a logout.  If this session runs for more than a day, things
+  -- stop working
+  --
+  local currTime = os.clock()
+  local diff = currTime - internalState.loginTime
+  if diff > globals.nSessionTimeout then 
+    cmdUrl = string.format(globals.strCmdLogout, internalState.strMailServer)
+    log.dbg("Sending Logout URL: " .. cmdUrl .. "\n")
+    local body, err = browser:get_uri(cmdUrl)
+ 
+    log.dbg("Logout forced to keep juno/netzero session fresh and tasty!  Yum!\n")
+    log.dbg("Session removed - Account: " .. internalState.strUser .. 
+      "@" .. internalState.strDomain .. "\n")
+    session.remove(hash())
+    return POPSERVER_ERR_OK
+  end
+
   -- Save and then Free up the session
   --
   session.save(hash(), serialize_state(), session.OVERWRITE)
@@ -956,7 +997,7 @@ function stat(pstate)
   local function funcProcess(body)
     -- Find out if there are any messages
     -- 
-    local _, _, nomesg = string.find(body, globals.strMsgListNoMsgPat)
+    local nomesg = string.match(body, globals.strMsgListNoMsgPat)
     if (nomesg ~= nil) then
       return true, nil
     end
@@ -981,7 +1022,7 @@ function stat(pstate)
 
       -- Convert the size from it's string (4K) to bytes
       --
-      --_, _, size = string.find(size, globals.strSizePattern)
+      --size = string.match(size, globals.strSizePattern)
       size = math.max(tonumber(size), 0) * 1024
 
       -- Save the information
@@ -1007,7 +1048,7 @@ function stat(pstate)
     -- Look in the body and see if there is a link for a next page
     -- If so, change the URL
     --
-    local _, _, nextURL = string.find(body, globals.strMsgListNextPagePattern)
+    local nextURL = string.match(body, globals.strMsgListNextPagePattern)
     if nextURL ~= nil then
       nPage = nPage + 1
       cmdUrl = baseUrl .. "&block=" .. nPage
@@ -1033,8 +1074,8 @@ function stat(pstate)
 
     -- Is the session expired
     --
-    local _,_,strSessExpr = string.find(body, globals.strRetLoginSessionExpired)
-    if strSessExpr ~= nil then
+    local strSessExpr = string.match(body, globals.strRetLoginSessionExpired)
+    if strSessExpr == nil then
       -- Invalidate the session
       --
       internalState.bLoginDone = nil
