@@ -17,7 +17,7 @@
 -- ************************************************************************** --
 --  FreePOPs @libero.it, @inwind.it, @blu.it, @iol.it webmail interface
 --  
---  $Id: libero.lua,v 1.50 2006/03/15 12:57:45 alessiofender Exp $
+--  $Id: libero.lua,v 1.57 2007/06/18 12:46:22 gareuselesinge Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -27,11 +27,11 @@
 -- fill them in the right way
 
 -- single string, all required
-PLUGIN_VERSION = "0.2.6"
+PLUGIN_VERSION = "0.2.12"
 PLUGIN_NAME = "Libero.IT"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=libero.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=libero.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 
 -- list of strings, one required, one contact for each author
@@ -98,10 +98,14 @@ local libero_string = {
 	-- to cut and paste the html source and work on it. For example
 	-- you could copy a message table row in a blank file, substitute
 	-- every useless field with '.*'.
-	statE = ".*<script>.*TREv.*</script>.*<TD.*>.*<input.*value.*=.*[[:digit:]]+.*>.*</TD>.*<TD>.*<div.*>.*</TD>.*<TD.*>.*<IMG.*>.*</TD>.*<TD>.*<div.*>.*</TD>.*<TD.*>.*<[Iid][Mmi][Ggv].*>.*</TD>.*<TD>.*<div.*>.*</TD>.*<TD.*>.*<a>.*<script>IMGEv.*</script>.*</a>.*<script>AEv.*</script>[.*]{b}.*{/b}[.*]</a>.*</TD>.*<TD>.*<div.*>.*</TD>.*<TD.*>.*<script>.*AEv.*</script>[.*]{b}.*{/b}[.*]</a>.*</TD>.*<TD>.*<div.*>.*</TD>.*<script>.*TDEv.*</script>[.*]{b}.*{/b}[.*]</TD>[.*]{!--.*--}.*<TD.*>.*<div.*>.*</TD>.*<script>TDEv.*</script>[.*]{b}.*[[:digit:]]+.*{/b}[.*]</TD>[.*]{!--.*--}.*</TR>",
+	 
+	statE = ".*<a.*doitMsg.*>[.*]{!--.*--}.*<script>.*IMGEv.*</script>.*</a>.*<script>.*AEv.*</script>[.*]{!--.*--}.*<script>.*</script>.*</a>.*</TD>.*<TD>.*<div>.*</TD>.*<TD>.*<script>.*</script>[.*]{!--.*--}.*<script>.*</script>.*</a>.*</TD>.*<TD>.*<div>.*</TD>.*<script>.*</script>[.*]{b}.*{/b}[.*]</TD>[.*]{!--.*--}.*<TD>.*<div>.*</TD>.*<script>.*</script>[.*]{b}.*{/b}[.*]</TD>[.*]{!--.*--}.*</TR>";
+	
 	-- This is the mlex get expression to choose the important fields 
 	-- of the message list page. Used in combination with statE
-	statG = "O<O><O>O<O>O<X>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O><O>O<O>O<O><O>[O]{O}O{O}[O]<O>O<O>O<O>O<O>O<O>O<O>O<O><O>[O]{O}O{O}[O]<O>O<O>O<O>O<O>O<O>O<O><O>[O]{O}O{O}[O]<O>[O]{O}O<O>O<O>O<O>O<O><O>[O]{O}X{O}[O]<O>[O]{O}O<O>",
+	
+	statG = "O<X>[O]{O}O<O>O<O>O<O>O<O>O<O>[O]{O}O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>[O]{O}O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>O<O>[O]{O}O{O}[O]<O>[O]{O}O<O>O<O>O<O>O<O>O<O>[O]{O}X{O}[O]<O>[O]{O}O<O>";
+	
 	-- The uri for the first page with the list of messages
 	first = "http://%s/cgi-bin/webmail.cgi?ID=%s&Act_Msgs=1&"..
 		"C_Folder=%s",
@@ -440,8 +444,9 @@ function stat(pstate)
 	local function action_f (s) 
 		-- calls match on the page s, with the mlexpressions
 		-- statE and statG
+		-- print(s)
 		local x = mlex.match(s,libero_string.statE,libero_string.statG)
-		-- x:print()
+		 x:print()
 		
 		-- the number of results
 		local n = x:count()
@@ -463,9 +468,10 @@ function stat(pstate)
 
 			-- arrange message size
 			local k = nil
-			_,_,k = string.find(size,"([Kk][Bb])")
-			_,_,size = string.find(size,"(%d+)")
-			_,_,uidl = string.find(uidl,"value=\"(%d+)\"")
+			k = string.match(size,"([Kk][Bb])")
+			size = string.match(size,"(%d+)")
+			--uidl = string.match(uidl,"value=\"(%d+)\"")
+			uidl = string.match(uidl, "doitMsg.'Act_View',%d+,%d+,'(%d+)'")
 			size = tonumber(size) + 2
 			if k ~= nil then
 				size = size * 1024
@@ -509,7 +515,7 @@ function stat(pstate)
 			return f,err
 		end
 
-		local _,_,c = string.find(f,libero_string.timeoutC)
+		local c = string.match(f,libero_string.timeoutC)
 		if c ~= nil then
 			internal_state.login_done = nil
 			session.remove(key())
