@@ -2,27 +2,27 @@
 --  FreePOPs @mail.com webmail interface
 --  
 --  Released under the GNU/GPL license
---  Written by Russell Schwager <russells@despammed.com>
+--  Written by Russell Schwager <russell822@yahoo.com>
 -- ************************************************************************** --
 
 -- Globals
 --
-PLUGIN_VERSION = "0.1.00"
+PLUGIN_VERSION = "0.1.05"
 PLUGIN_NAME = "mail.com"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=mailcom.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=mailcom.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager"}
 PLUGIN_AUTHORS_CONTACTS = 
-	{"russells (at) despammed (.) com"}
+	{"russell822 (at) yahoo (.) com"}
 PLUGIN_DOMAINS = {"@mail.com","@email.com","@iname.com","@cheerful.com","@consultant.com",
 "@europe.com","@mindless.com","@earthling.net","@myself.com","@post.com",
 "@techie.com","@usa.com","@writeme.com","@2die4.com","@artlover.com",
 "@bikerider.com","@catlover.com","@cliffhanger.com","@cutey.com",
 "@doglover.com","@gardener.com","@hot-shot.com","@inorbit.com",
 "@loveable.com","@mad.scientist.com","@playful.com","@poetic.com",
-"@popstar.com","@saintly.com","@seductive.com","@soon.com",
+"@popstar.com","@popstarmail.org","@saintly.com","@seductive.com","@soon.com",
 "@whoever.com","@winning.com","@witty.com","@yours.com","@africamail.com",
 "@arcticmail.com","@asia.com","@australiamail.com","@europe.com",
 "@japan.com","@samerica.com","@usa.com","@berlin.com","@dublin.com",
@@ -70,7 +70,7 @@ PLUGIN_DOMAINS = {"@mail.com","@email.com","@iname.com","@cheerful.com","@consul
 "@webcity.ca","@webmail.lu","@welcomm.ac","@wenxuecity.net","@westham-mail.com","@wimbledon-mail.com",
 "@windrivers.net","@wolves-mail.com","@wongfaye.com","@worldmail.ac","@worldweb.ac","@isleuthmail.com",
 "@x-lab.cc","@xy.com.tw","@yankeeman.com","@yyhmail.com", "@verizonmail.com", "@lycos.com", "@cyberdude.com",
-"@mail.org", "@italymail.com", "@mexico.com" }
+"@mail.org", "@italymail.com", "@mexico.com", "@india.com", "@u2club.com" }
 PLUGIN_PARAMETERS = {
 	{name = "folder", description = {
 		en = [[
@@ -114,6 +114,7 @@ local globals = {
   strLoginPage2 = "http://%s.%s/scripts/common/login.main",
   strLoginPage3 = "http://%s.%s/scripts/lycos/lyproxy.main",
   strLoginPage4 = "http://super.japan.com/scripts/common/ss_main.cgi",
+  strLoginPage5 = "http://super.popstarmail.org/scripts/common/ss_main.cgi",
   strLoginPostData = "show_frame=Enter&mail_language=us&action=login&login=%s%%40%s&password=%s&domain=%s&siteselected=normal&",
   strLoginPostData2 = "show_frame=Enter&mail_language=us&action=login&login=%s&password=%s&domain=%s&siteselected=normal&",
 
@@ -255,7 +256,7 @@ function postToLoginPage(browser, url, post, attempt)
 
   -- Check for invalid login/password
   -- 
-  local _, _, str = string.find(body, globals.strRetLoginBadPassword)
+  local str = string.match(body, globals.strRetLoginBadPassword)
   if str ~= nil then
     log.error_print("Login Failed: Invalid username/Password")
     return POPSERVER_ERR_AUTH
@@ -263,7 +264,7 @@ function postToLoginPage(browser, url, post, attempt)
 
   -- Extract the mail server
   --
-  _, _, str = string.find(body, globals.strRegExpMailServer)
+  str = string.match(body, globals.strRegExpMailServer)
   if str == nil then
     log.error_print("Login Failed: Unable to detect mail server - Attempt: " .. attempt)
     return POPSERVER_ERR_UNKNOWN
@@ -301,7 +302,7 @@ function login()
 
   if (domain == "email.com" or domain == "iname.com" or domain ==  
 "mail.org") then
-    url = string.format(globals.strLoginPage, "www", "mail.com")
+    url = string.format(globals.strLoginPage, "www2", "mail.com")
   elseif (domain == "usa.com" or domain == "mexico.com") then
     url = string.format(globals.strLoginPage, "mail", domain)
   elseif (domain == "lycos.com") then
@@ -311,6 +312,8 @@ function login()
     url = string.format(globals.strLoginPage2, "www", "otakumail.com")
   elseif (domain == "japan.com") then
     url = globals.strLoginPage4
+  elseif (domain == "wongfaye.com" or domain == "u2club.com") then
+    url = globals.strLoginPage5
   else
     url = string.format(globals.strLoginPage, "www", domain)
   end
@@ -326,7 +329,7 @@ function login()
   -- Error checking
   --
   if (retval == POPSERVER_ERR_UNKNOWN or retval == POPSERVER_ERR_NETWORK or retval == POPSERVER_ERR_AUTH) then
-    url = string.format(globals.strLoginPage, "www", "mail.com")
+    url = string.format(globals.strLoginPage, "www2", "mail.com")
     retval = postToLoginPage(browser, url, post, 2)  
     if (retval ~= POPSERVER_ERR_OK) then
       return retval
@@ -479,7 +482,8 @@ end
 
 function getPage(browser, url)
   local body, err = browser:get_uri(url)
-  if string.find(body, "(session is sponsored by)") ~= nil then
+  if (string.find(body, "(session is sponsored by)") ~= nil or 
+     string.find(body, '("Remove these ads")')) then
     body, err = browser:get_uri(url)
   end
   return body, err  
@@ -491,9 +495,9 @@ function cleanupHeaders(headers)
   --
   local origHeaders = headers
   if (internalState.strDomain == "otakumail.com") then
-    _, _, headers = string.find(headers, "(From:.-)</font></td></tr>")
+    headers = string.match(headers, "(From:.-)</font></td></tr>")
   else
-    _, _, headers = string.find(headers, '(From:.-)ml_header')
+    headers = string.match(headers, '(From:.-)ml_header')
   end
   if (headers == nil) then
     log.dbg("Unable to parse out message body headers!")
@@ -805,7 +809,7 @@ function stat(pstate)
 
     -- Is the session expired
     --
-    local _, _, strSessExpr = string.find(body, globals.strRetLoginSessionExpired)
+    local strSessExpr = string.match(body, globals.strRetLoginSessionExpired)
     if strSessExpr == nil then
       -- Invalidate the session
       --
@@ -833,9 +837,9 @@ function stat(pstate)
     -- Get the total number of messages
     --
     if nTotMsgs == 0 then
-      _, _, nTotMsgs = string.find(body, globals.strMsgListCntPattern)
+      nTotMsgs = string.match(body, globals.strMsgListCntPattern)
       if nTotMsgs == nil then -- Try a different pattern
-        _, _, nTotMsgs = string.find(body, globals.strMsgListCntPattern2)
+        nTotMsgs = string.match(body, globals.strMsgListCntPattern2)
       end
 
       if nTotMsgs == nil then
