@@ -1,7 +1,7 @@
 -- ************************************************************************** --
 --  FreePOPs pop3 forwarding plugin
 -- 
---  $Id: popforward.lua,v 1.18 2006/01/26 10:41:37 gareuselesinge Exp $
+--  $Id: popforward.lua,v 1.20 2007/01/14 16:49:37 gareuselesinge Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -11,11 +11,11 @@
 -- WARNING        the bindings for psock in lua are really poor       WARNING --
 -- ************************************************************************** --
 
-PLUGIN_VERSION = "0.0.3"
+PLUGIN_VERSION = "0.0.4"
 PLUGIN_NAME = "POPforward"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=popforward.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=popforward.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Enrico Tassi"}
 PLUGIN_AUTHORS_CONTACTS = {"gareuselesinge (at) users (.) sourceforge (.) net"}
@@ -178,7 +178,7 @@ function user(pstate,username)
 		return POPSERVER_ERR_AUTH
 	end
 	
-	local _,_,host,port=string.find(freepops.MODULE_ARGS.host,"(.*):(%d+)")
+	local host,port=string.match(freepops.MODULE_ARGS.host,"(.*):(%d+)")
 	if host == nil then
 		host = freepops.MODULE_ARGS.host
 	end
