@@ -1,18 +1,18 @@
 -- ************************************************************************** --
 --  FreePOPs @--put here domain-- webmail interface
 -- 
---  $Id: skeleton.lua,v 1.10 2006/01/15 19:43:15 gareuselesinge Exp $
+--  $Id: skeleton.lua,v 1.12 2007/01/14 16:49:37 gareuselesinge Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by --put Name here-- <--put email here-->
 -- ************************************************************************** --
 
-PLUGIN_VERSION = "---put version here---"
+PLUGIN_VERSION = "---put_version_here---"
 PLUGIN_NAME = "---put name here---"
 PLUGIN_REQUIRE_VERSION = "---fill---"
 PLUGIN_LICENSE = "GNU/GPL"
 PLUGIN_URL = "http://www.freepops.org"
-PLUGIN_HOMEPAGE = "http://www.freepops.org/download.php?file=skeleton.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/download.php?module=skeleton.lua"
 PLUGIN_AUTHORS_NAMES = {"---fill--- "}
 PLUGIN_AUTHORS_CONTACTS = {"---fill---"}
 PLUGIN_DOMAINS = {"@..."}
