@@ -4,21 +4,23 @@
 --  Released under the GNU/GPL license
 --  Written by Russell Schwager <russells@despammed.com>
 --  yahoo.it added by Nicola Cocchiaro <ncocchiaro@users.sourceforge.net>
+--  yahoo.ie added by Bruce Williamson <aztrix@yahoo.com>
+--  Contributions by Przemyslaw Wroblewski <przemyslaw.wroblewski@gmail.com>
 -- ************************************************************************** --
 
 -- Globals
 --
-PLUGIN_VERSION = "0.1.9b"
+PLUGIN_VERSION = "0.1.9j"
 PLUGIN_NAME = "yahoo.com"
-PLUGIN_REQUIRE_VERSION = "0.0.97"
+PLUGIN_REQUIRE_VERSION = "0.2.0"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://www.freepops.org/download.php?file=yahoo.lua"
+PLUGIN_URL = "http://www.freepops.org/download.php?module=yahoo.lua"
 PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager","Nicola Cocchiaro"}
 PLUGIN_AUTHORS_CONTACTS = 
 	{"russells (at) despammed (.) com",
          "ncocchiaro (at) users (.) sourceforge (.) net"}
-PLUGIN_DOMAINS = {"@yahoo.com","@yahoo.it", "@yahoo.ca", "@rocketmail.com", "@yahoo.com.ar",
+PLUGIN_DOMAINS = {"@yahoo.com", "@yahoo.ie", "@yahoo.it", "@yahoo.ca", "@rocketmail.com", "@yahoo.com.ar",
                   "@yahoo.co.in", "@yahoo.com.tw", "@yahoo.co.uk", "@yahoo.com.cn",
                   "@yahoo.es", "@yahoo.de", "@talk21.com", "@btinternet.com", "@yahoo.com.au",
 }
@@ -106,11 +108,12 @@ local globals = {
   strLoginPage = "http://login.yahoo.com",
   strLoginHTTP = "http://login.yahoo.com/config/login",   
   strLoginHTTPs = "https://login.yahoo.com/config/login",   
-  strLoginPostData = ".tries=1&.src=ym&.intl=%s&login=%s&passwd=%s&.persistent=y",
+  strLoginPostData = ".tries=1&.src=ym&.intl=%s&login=%s&passwd=%s&.persistent=y&.v=0&.chkP=Y&.u=%s",
   strLoginPostDataMD5 = ".tries=1&.src=ym&.intl=%s&login=%s&passwd=%s&.hash=1"..
-                        "&.md5=1&.js=1&.challenge=%s&.persistent=y",
+                        "&.md5=1&.js=1&.challenge=%s&.persistent=y&.v=0&.chkP=Y&.u=%s",
   strLoginFailed = "Login Failed - Invalid User name and password",
   strLoginChallenge = 'name="%.challenge" value="([^"]-)"',
+  strLoginU = 'name="%.u" value="([^"]-)"',
 
   -- Expressions to pull out of returned HTML from Yahoo corresponding to a problem
   --
@@ -232,8 +235,15 @@ local globals = {
 
   -- SOAP Urls
   --
-  strSoapCmd = "%s%s?m=%s&wssid=%s", 
-  strCmdAttach = "%sym/cgdownload/?box=%s&MsgId=%s&bodyPart=%s&download=1",
+  strSoapCmd = "%s%s?m=%s&wssid=%s&appid=YahooMailRC", 
+  --strCmdAttach = "%sya/download?fid=%s&mid=%s&pid=2&tnef=&YY=189019855&newid=1&clean=0&inline=1",
+  strCmdAttach = "%sya/download?fid=%s&mid=%s&pid=%s&tnef=&clean=0&redirectURL=%sdc/virusresults.html%%3Ffrom%%3Ddownload_response%%26ui%%3Diframe%%26YY%%3D1163030279984",
+
+--"%sym/cgdownload/?box=%s&MsgId=%s&bodyPart=%s&download=1",
+--"%sya/download?fid=%s&mid=%s&pid=%s&tnef=&clean=0&",                   
+
+  strRedirectNew = 'content="0; url=([^"]+)">',
+  strYahooxlms = "ymws",
 
   -- SOAP Constants
   --
@@ -246,8 +256,9 @@ local globals = {
 
   -- Data Recognization on login
   --
-  strRegExpCrumbNew = "wssid : '([^']+)'",
-  strRegExpWebSrvUrl = "webserviceUrl: '([^']+)'", 
+--  strRegExpCrumbNew = "wssid : '([^']+)'",
+  strRegExpCrumbNew = "wssid[^:]+: '([^']+)'",
+  strRegExpWebSrvUrl = "webservice[^:]-: '([^']+)'", 
 
   -- Folder names
   --
@@ -391,7 +402,7 @@ end
 -- Check to see if the GUI is the new one
 --
 function checkForNewGUI(browser, body)
-  local _, _, server = string.find(browser:whathaveweread(), globals.strRegExpMailServerNew)
+  local server = string.match(browser:whathaveweread(), globals.strRegExpMailServerNew)
   if (server ~= nil) then 
     log.dbg("Detected New Version of the Yahoo interface!\n")
     log.raw("Detected New Version of the Yahoo interface!\n")
@@ -431,7 +442,7 @@ function loginYahoo()
   local url = globals.strLoginHTTP
   local browser = internalState.browser
   local post
-  local challengeCode
+  local challengeCode, uVal
 
   -- Handle rocketmail
   --
@@ -461,20 +472,31 @@ function loginYahoo()
   local body, err = browser:get_uri(globals.strLoginPage)
   
   if body ~= nil then
-    _, _, challengeCode = string.find(body, globals.strLoginChallenge)
+    challengeCode = string.match(body, globals.strLoginChallenge)
+    uVal = string.match(body, globals.strLoginU)
+  end
+
+  if (uVal == nil) then
+    uVal = ""
   end
 
   if challengeCode ~= nil then
     password = crypto.bin2hex(crypto.md5(password))
     password = crypto.bin2hex(crypto.md5(password .. challengeCode))
     post = string.format(globals.strLoginPostDataMD5, intFlag, username,
-                         password, challengeCode)
+                         password, challengeCode, uVal)
   else -- if we didn't get the challenge code, then login in cleartext
-    post = string.format(globals.strLoginPostData, intFlag, username, password)
+    post = string.format(globals.strLoginPostData, intFlag, username, password, uVal)
   end
-
   body, err = browser:post_uri(url, post)
 
+  -- Check for redirect
+  --
+  local str = string.match(body, globals.strRedirectNew)
+  if (str ~= nil) then
+    body, err = browser:get_uri(str)
+  end
+
   local bNewGui = checkForNewGUI(browser, body)
 
   if (bNewGui == true) then
@@ -490,9 +512,15 @@ function loginYahoo()
     return POPSERVER_ERR_NETWORK
   end
 
+  local str = string.match(body, '<input type="text" id="secword" name=".secword"')
+  if (str ~= nil) then
+    log.error_print("Login Failed: Yahoo is using an image verification.  Please login through the web.")
+    return POPSERVER_ERR_NETWORK
+  end
+
   -- Check for invalid password
   -- 
-  local _, _, str = string.find(body, globals.strRetLoginBadPassword)
+  local str = string.match(body, globals.strRetLoginBadPassword)
   if str ~= nil then
     log.raw("------ Returned Page saying invalid password ------\n")
     log.raw(body)
@@ -503,9 +531,10 @@ function loginYahoo()
 
   -- Extract the mail server
   --
-  local _, _, str = string.find(body, globals.strRegExpMailServer)
+  local str = string.match(body, globals.strRegExpMailServer)
   if str == nil then
     log.error_print("Login Failed: Unable to find mail server")
+    log.raw("Unable to find mail server: " .. body)
     return POPSERVER_ERR_UNKNOWN
   else
     internalState.strMailServer = str
@@ -514,7 +543,7 @@ function loginYahoo()
   -- If we are using HTTPS, we need to look for the meta-refresh link
   -- returned by the login response and go to it.
   if (challengeCode ~= nil) then
-    _, _, str = string.find(body, globals.strRegExpMetarefresh)
+    str = string.match(body, globals.strRegExpMetarefresh)
     if (str ~= nil) then
       body, err = browser:get_uri(str)
       
@@ -550,25 +579,29 @@ end
 function loginNewYahoo(browser, body) 
   -- Let's get the crumb value
   --
-  local _, _, str = string.find(body, globals.strRegExpCrumbNew)
+  local str = string.match(body, globals.strRegExpCrumbNew)
   if str == nil then
     log.error_print("Yahoo - unable to parse out crumb value.  Deletion will fail.")
     log.raw("Yahoo - unable to parse out crumb value.  Deletion will fail, Body: " .. 
       body)
     return POPSERVER_ERR_UNKNOWN
   end
+  log.dbg("Crumb Value: " .. str)
   internalState.strCrumb = str
 
   -- Get the Web Service Url
   --
-  local _, _, str = string.find(body, globals.strRegExpWebSrvUrl)
-  if str == nil then
-    log.error_print("Yahoo - unable to parse out web service Url.")
-    log.raw("Yahoo - unable to parse out web service value.  Body: " .. 
-      body)
-    return POPSERVER_ERR_UNKNOWN
-  end
-  internalState.strWebSrvUrl = str
+--  local str = string.match(body, globals.strRegExpWebSrvUrl)
+--  if str == nil then
+--    log.error_print("Yahoo - unable to parse out web service Url.")
+--    log.raw("Yahoo - unable to parse out web service value.  Body: " .. 
+--      body)
+--    return POPSERVER_ERR_UNKNOWN
+--    str = "ws/mail/v1/soap"
+--  end
+  -- We used to query for this.
+  --
+  internalState.strWebSrvUrl = "ws/mail/v1/soap"
 
   -- Get metadata
   --
@@ -689,35 +722,38 @@ function downloadYahooMsg(pstate, msg, nLines, data)
 
   -- Start the download on the body
   -- 
-  if nLines ~= 0 then
-    if (internalState.bNewGUI) then
-      headers = mimer.remove_lines_in_proper_mail_header(headers, {"content%-type",
+  if (internalState.bNewGUI) then
+    headers = mimer.remove_lines_in_proper_mail_header(headers, {"content%-type",
 		"content%-disposition", "mime%-version", "boundary"})
 
+
+    if nLines == 0 then
+      cbInfo.strText = ""
+    else
       getMsgBody(pstate, uidl, size, cbInfo)
-      mimer.pipe_msg(
-        headers, 
-        cbInfo.strText, 
-        cbInfo.strHtml, 
-        internalState.strMailServer, 
-        cbInfo.attachments, browser, 
-        function(s)
-          popserver_callback(s,data)
-        end, cbInfo.inlineids)
-    else 
-      local f, _ = browser:pipe_uri(bodyUrl,cb)
-      if not f then
-        -- An empty message.  Send the headers anyway
-        --
-        log.dbg("Empty message")
-      else
-        -- Just send an extra carriage return
-        --
-        log.dbg("Message Body has been processed.")
-        if (cbInfo.strBuffer ~= "\r\n") then
-          log.dbg("Message doesn't end in CRLF, adding to prevent client timeout.")
-          popserver_callback("\r\n\0", data)
-        end
+    end
+    mimer.pipe_msg(
+      headers, 
+      cbInfo.strText, 
+      cbInfo.strHtml, 
+      internalState.strMailServer, 
+      cbInfo.attachments, browser, 
+      function(s)
+        popserver_callback(s,data)
+      end, cbInfo.inlineids)
+  elseif (nLines ~= 0) then  
+    local f, _ = browser:pipe_uri(bodyUrl,cb)
+    if not f then
+      -- An empty message.  Send the headers anyway
+      --
+      log.dbg("Empty message")
+    else
+      -- Just send an extra carriage return
+      --
+      log.dbg("Message Body has been processed.")
+      if (cbInfo.strBuffer ~= "\r\n") then
+        log.dbg("Message doesn't end in CRLF, adding to prevent client timeout.")
+        popserver_callback("\r\n\0", data)
       end
     end
   end
@@ -732,7 +768,7 @@ function downloadYahooMsg(pstate, msg, nLines, data)
       local cmdUrl = string.format(globals.strCmdMsgWebView, internalState.strMailServer,
         internalState.strMBox, msgid);
       local str, _ = browser:get_uri(cmdUrl) 
-      _, _, str = string.find(str, globals.strMsgMarkUnreadPat)
+      str = string.match(str, globals.strMsgMarkUnreadPat)
       if str == nil then
         log.warn("Unable to get the url for marking message as unread.")
       else
@@ -840,14 +876,10 @@ function getUserMetaData()
     internalState.strWebSrvUrl, "GetMetaData", internalState.strCrumb)
 
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "GetMetaData", 
+    url, "urn:yahoo:" .. globals.strYahooxlms, "GetMetaData", 
       {
         {
-          tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid }
-            }
+          tag = "param1", ""
         },
       })
 
@@ -861,32 +893,32 @@ function getUserData()
   local url = string.format(globals.strSoapCmd, internalState.strMailServer, 
     internalState.strWebSrvUrl, "GetUserData", internalState.strCrumb)
 
-  local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "GetUserData", 
-      {
-        {
-          tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid }
-            }
-        },
-      })
+--  local ns, meth, ent, err = soap.http.call(browser,
+--    url, "urn:yahoo:" .. globals.strYahooxlms, "GetUserData", 
+--      {
+--        {
+--          tag = "param1",
+--            { tag = "greq", 
+--              attr = { ["gve"] = globals.strGre_Gve },
+--                { tag = "gid", globals.strGre_Gid }
+--            }
+--        },
+--      })
 
   -- Need to grab the gres, gss element
   --
-  local str = nil
-  for i, elem in ipairs (ent[2]) do
-    if (elem["tag"] == "gss") then
-      str = elem[1]
-    end
-  end
+--  local str = nil
+--  for i, elem in ipairs (ent[2]) do
+--    if (elem["tag"] == "gss") then
+--      str = elem[1]
+--    end
+--  end
 
-  if (str == nil) then
-    log.error_print("Unable to parse out the gss value.")
-    return 1
-  end
-  internalState.strGSS = str
+--  if (str == nil) then
+--    log.error_print("Unable to parse out the gss value.")
+--    return 1
+--  end
+--  internalState.strGSS = str
 
   return 0
 end
@@ -897,15 +929,10 @@ function getFolderList()
     internalState.strWebSrvUrl, "ListFolders", internalState.strCrumb)
 
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "ListFolders", 
+    url, "urn:yahoo:" .. globals.strYahooxlms, "ListFolders", 
       {
         {
           tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            },
             { tag = "resetunseen", "true" } 
         },
       })
@@ -916,39 +943,29 @@ end
 function getSTATList(pstate)
   local browser = internalState.browser
   local url = string.format(globals.strSoapCmd, internalState.strMailServer, 
-    internalState.strWebSrvUrl, "LstMsgs", internalState.strCrumb)
+    internalState.strWebSrvUrl, "ListMessages", internalState.strCrumb)
   local nMaxMsgs = 999 
   if internalState.statLimit ~= nil then
     nMaxMsgs = internalState.statLimit
   end
 
-  local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "LstMsgs", 
-      {
-        { tag = "param1",
-            attr = {
-              ["startMid"] = "0",
-              ["numMid"] = nMaxMsgs,
-              ["startInfo"] = "0",
-              ["numInfo"] = nMaxMsgs,
-              ["startBody"] = "0",
-              ["numBody"] = "0",
-            },
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            },
-            { tag = "sortKey", "date" }, 
-            { tag = "sortOrder", "down" }, 
-            { tag = "flags", "" }, 
-            { tag = "fi",
-                attr = { ["fname"] = internalState.strMBox }, 
-                ""
-            },
-          }, 
-      })
+  local body = {   
+        { tag = "sortKey", "date" }, 
+        { tag = "sortOrder", "down" }, 
+        { tag = "filterBy", "" }, 
+        { tag = "fid", internalState.strMBox }, 
+        { tag = "transform-markup", "remove-javascript" },
+      }
+  body.attr = { 
+        ["startMid"] = "0",
+        ["numMid"] = nMaxMsgs,
+        ["startInfo"] = "0",
+        ["numInfo"] = nMaxMsgs,
+        ["numBody"] = "0",
+  }
 
+  local ns, meth, ent, err = soap.http.call(browser,
+    url, "urn:yahoo:" .. globals.strYahooxlms, "ListMessages", body)
 
   -- Initialize our state
   --
@@ -964,16 +981,10 @@ function getSTATList(pstate)
   end
 
   for i, elem in ipairs (ent) do
-    if (type(elem) == "table" and elem["tag"] == "minfo") then
+    if (type(elem) == "table" and elem["tag"] == "messageInfo") then
       local attrs = elem["attr"]
-      local size = attrs["msize"]     
-
-      local subelem = elem[1]
-      if (subelem["tag"] ~= "mid") then
-        log.error_print("Unable to parse out the message id")
-        return POPSERVER_ERR_NETWORK
-      end
-      local uidl = subelem[1]
+      local size = attrs["size"]     
+      local uidl = attrs["mid"]
 
       -- Save the information
       --
@@ -994,29 +1005,21 @@ function getMsgHdr(pstate, uidl)
   local url = string.format(globals.strSoapCmd, internalState.strMailServer, 
     internalState.strWebSrvUrl, "GetMessageRawHeader", internalState.strCrumb)
 
+  local body = {   
+        { tag = "mid", uidl }, 
+        { tag = "fid", internalState.strMBox }, 
+      }
+
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "GetMessageRawHeader", 
-      {
-        { tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            },
-            { tag = "mid", uidl }, 
-            { tag = "fi",
-                attr = { ["fname"] = internalState.strMBox }, 
-                ""
-            },
-          }, 
-      })
+    url, "urn:yahoo:" .. globals.strYahooxlms, "GetMessageRawHeader", body)
 
   -- Get the header
   --
   local header = nil
   for i, elem in ipairs (ent) do
-    if (type(elem) == "table" and elem["tag"] == "mhd") then
+    if (type(elem) == "table" and elem["tag"] == "rawheaders") then
       header = elem[1]
+      header = header .. "\n"
     end
   end
 
@@ -1033,57 +1036,55 @@ end
 function getMsgBody(pstate, uidl, size, cbInfo)
   local browser = internalState.browser
   local url = string.format(globals.strSoapCmd, internalState.strMailServer, 
-    internalState.strWebSrvUrl, "GetMessageBodyPart", internalState.strCrumb)
+    internalState.strWebSrvUrl, "GetMessage", internalState.strCrumb)
+
+  local body = {   
+        { tag = "mid", uidl }, 
+        { tag = "fid", internalState.strMBox }, 
+        { tag = "truncateAt", "999999" }, 
+      }
 
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "GetMessageBodyPart", 
-      {
-        { tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve, ["gdk"] = "1" },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            },
-            { tag = "mid", uidl }, 
-            { tag = "truncateAt", 999999999 }, 
-            { tag = "fi",
-                attr = { ["fname"] = internalState.strMBox }, 
-                ""
-            },
-          }, 
-      })
+    url, "urn:yahoo:" .. globals.strYahooxlms, "GetMessage", body)
 
   -- Get the parts
   --
   local part = nil
-  for i, elem in ipairs (ent[2]) do
+  for i, elem in ipairs (ent[3]) do
     if (type(elem) == "table" and elem["tag"] == "part") then
       part = elem
       local attrs = elem["attr"]
-      local subtype = attrs["subType"]
+      local partId = attrs["partId"]
+      local type = attrs["type"]
+      local subtype = attrs["subtype"]
       if (subtype == "plain") then
         local textElem = elem[1]
         local text = textElem[1]
+        text = text .. "\n"
         cbInfo.strText = getMsgCallBack(cbInfo, text)
       elseif (subtype == "html") then
         local textElem = elem[1]
         local text = textElem[1]
-        text = string.gsub(text, "(</[^>]+>) ", "%1\r\n") 
+        text = string.gsub(text, "&amp;", "&")
+--        text = string.gsub(text, "(</[^>]+>) ", "%1\r\n") 
+        text = text .. "\n"
         cbInfo.strHtml = getMsgCallBack(cbInfo, text)
+      elseif (partId == "HEADER" or partId == "TEXT") then
+        -- no-op
       else
-        local partId = attrs["partId"]
         local file = attrs["dispParams"]
         local contentId = attrs["contentId"]
         if (file ~= nil) then
           file = string.gsub(file, "^.-=", "")
+          local escUidl = string.gsub(uidl, "%+", "%%2B")
           url = string.format(globals.strCmdAttach, internalState.strMailServer,
-             internalState.strMBox, uidl, partId)
-          cbInfo.attachments[file] = url
-          table.setn(cbInfo.attachments, table.getn(cbInfo.attachments) + 1)
+             internalState.strMBox, escUidl, partId, internalState.strMailServer)
+          cbInfo.attachments[file] = getRealAttachmentUrl(url)
+          table.insert(cbInfo.attachments, table.getn(cbInfo.attachments) + 1, cbInfo.attachments[file])
           if (contentId ~= nil) then
             contentId = string.sub(contentId, 2, -2)
             cbInfo.inlineids[file] = contentId
-            table.setn(cbInfo.inlineids, table.getn(cbInfo.inlineids) + 1)
+            table.insert(cbInfo.inlineids, table.getn(cbInfo.inlineids) + 1, contentId)
           end
         end
       end
@@ -1096,24 +1097,16 @@ end
 function markMsgUnread(uidl)
   local browser = internalState.browser
   local url = string.format(globals.strSoapCmd, internalState.strMailServer, 
-    internalState.strWebSrvUrl, "SetMessageFlag", internalState.strCrumb)
+    internalState.strWebSrvUrl, "FlagMessages", internalState.strCrumb)
 
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "SetMessageFlag", 
+    url, "urn:yahoo:" .. globals.strYahooxlms, "FlagMessages", 
       {
         { tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            },
             { tag = "mid", uidl }, 
-            { tag = "fi",
-                attr = { ["fname"] = internalState.strMBox }, 
-                ""
-            },
-            { tag = "flag",
-                attr = { ["seen"] = "0" }, 
+            { tag = "fid", internalState.strMBox }, 
+            { tag = "setFlags",
+                attr = { ["read"] = "0" }, 
                 ""
             },
           }, 
@@ -1126,20 +1119,9 @@ function emptyFolder(folderName)
     internalState.strWebSrvUrl, "EmptyFolder", internalState.strCrumb)
 
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "EmptyFolder", 
+    url, "urn:yahoo:" .. globals.strYahooxlms, "EmptyFolder", 
       {
-        {
-          tag = "param1",
-            { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            },
-            { tag = "fi",
-                attr = { ["fname"] = folderName }, 
-                ""
-            },
-        },
+            { tag = "fid", folderName }, 
       })
 
   return 0
@@ -1148,9 +1130,11 @@ end
 function deleteMsgs(pstate)
   local browser = internalState.browser
   local url = string.format(globals.strSoapCmd, internalState.strMailServer, 
-    internalState.strWebSrvUrl, "MoveMsgs", internalState.strCrumb)
+    internalState.strWebSrvUrl, "MoveMessages", internalState.strCrumb)
 
-  local param = { tag = "param1" }
+  local param = { }
+  table.insert(param, { tag = "sourceFid", internalState.strMBox })
+  table.insert(param, { tag = "destinationFid", globals.strTrash })
 
   -- Cycle through the messages and see if we need to delete any of them
   -- 
@@ -1168,28 +1152,28 @@ function deleteMsgs(pstate)
     return 0
   end
 
-  table.insert(param, { tag = "greq", 
-              attr = { ["gve"] = globals.strGre_Gve },
-                { tag = "gid", globals.strGre_Gid },
-                { tag = "gss", internalState.strGSS }
-            })
-  table.insert(param, { tag = "fi",
-                attr = { ["fname"] = internalState.strMBox }, 
-                ""
-            })
-  table.insert(param, { tag = "tofi",
-                attr = { ["fname"] = globals.strTrash }, 
-                ""
-            })
-  
-
   local ns, meth, ent, err = soap.http.call(browser,
-    url, "urn:yahoo:" .. internalState.strWebSrvUrl, "MoveMsgs", 
-      { param })
+    url, "urn:yahoo:" .. globals.strYahooxlms, "MoveMessages", 
+      param)
 
   return 0
 end
 
+-- Utility Function
+--
+function getRealAttachmentUrl(url)
+  local browser = internalState.browser
+  local h, err = browser:get_head(url, {}, true)
+  if (err ~= nil) then
+    log.dbg(err)
+    return nil
+  end
+  local x = string.match(h,
+                "[Ll][Oo][Cc][Aa][Tt][Ii][Oo][Nn]%s*:%s*([^\r]*)")
+  return (x or nil)
+end
+
+
 -- ************************************************************************** --
 --  Pop3 functions that must be defined
 -- ************************************************************************** --
@@ -1208,7 +1192,9 @@ function user(pstate, username)
 
   -- Figure out the domain specific flags
   --
-  if domain == "yahoo.it" then
+  if domain == "yahoo.ie" then
+    internalState.strIntFlag = globals.strYahooIe
+  elseif domain == "yahoo.it" then
     internalState.strIntFlag = globals.strYahooIt
   elseif domain == "yahoo.ca" then
     internalState.strIntFlag = globals.strYahooCa
@@ -1240,23 +1226,23 @@ function user(pstate, username)
   --
   local mbox = (freepops.MODULE_ARGS or {}).folder or globals.strInbox
   if mbox ~= globals.strInbox then
-    local _, _, str = string.find(globals.strInboxPat, "(" .. mbox .. ")")
+    local str = string.match(globals.strInboxPat, "(" .. mbox .. ")")
     if str ~= nil then
       mbox = globals.strInbox
     else
-      _, _, str = string.find(globals.strBulkPat, "(" .. mbox .. ")")
+      str = string.match(globals.strBulkPat, "(" .. mbox .. ")")
       if str ~= nil then
         mbox = globals.strBulk
       else
-        _, _, str = string.find(globals.strTrashPat, "(" .. mbox .. ")")
+        str = string.match(globals.strTrashPat, "(" .. mbox .. ")")
         if str ~= nil then
           mbox = globals.strTrash
         else
-          _, _, str = string.find(globals.strSentPat, "(" .. mbox .. ")")
+          str = string.match(globals.strSentPat, "(" .. mbox .. ")")
           if str ~= nil then
             mbox = globals.strSent
           else
-            _, _, str = string.find(globals.strDraftPat, "(" .. mbox .. ")")
+            str = string.match(globals.strDraftPat, "(" .. mbox .. ")")
             if str ~= nil then 
               mbox = globals.strDraft
             end
@@ -1266,16 +1252,17 @@ function user(pstate, username)
     end
   end
   
+  mbox = string.gsub(mbox, " ", "+") 
   internalState.strMBox = mbox
 
   -- Get the view to use in STAT (ALL, UNREAD or FLAG)
   --
   local strView = (freepops.MODULE_ARGS or {}).view or "All"
-  local _, _, str = string.find(strView, globals.strViewAllPat)
+  local str = string.match(strView, globals.strViewAllPat)
   if str ~= nil then
     internalState.strView = globals.strViewAll
   else
-    _, _, str = string.find(strView, globals.strViewUnreadPat)
+    str = string.match(strView, globals.strViewUnreadPat)
     if str ~= nil then
       internalState.strView = globals.strViewUnread
     else
@@ -1446,7 +1433,7 @@ function quit_update(pstate)
 
   -- Let's get the crumb value
   --
-  local _, _, strCrumb = string.find(internalState.strStatCache, globals.strRegExpCrumb)
+  local strCrumb = string.match(internalState.strStatCache, globals.strRegExpCrumb)
   if strCrumb == nil then
     log.error_print("Yahoo - unable to parse out crumb value.  Deletion will fail.")
     log.raw("Yahoo - unable to parse out crumb value.  Deletion will fail, Body: " .. 
@@ -1468,7 +1455,7 @@ function quit_update(pstate)
    
     -- Get the url to post to
     --
-    _, _, cmdUrl = string.find(internalState.strStatCache, globals.strDeletePostPat)
+    cmdUrl = string.match(internalState.strStatCache, globals.strDeletePostPat)
     if (cmdUrl == nil) then 
       log.error_print("Yahoo - unable to parse out delete url.  Deletion will fail.")
       log.raw("Yahoo - unable to parse out delete url.  Deletion will fail, Body: " .. 
@@ -1485,7 +1472,7 @@ function quit_update(pstate)
 
   -- Empty the trash
   --
-  local _, _, strAll = string.find(internalState.strStatCache, globals.strEmptyAllPat)
+  local strAll = string.match(internalState.strStatCache, globals.strEmptyAllPat)
   if internalState.bEmptyTrash then
     if strAll ~= nil then
       cmdUrl = string.format(globals.strCmdEmptyTrash, internalState.strMailServer) .. strAll
@@ -1571,14 +1558,14 @@ function stat(pstate)
   local function funcProcess(body)
     -- Find out if there are any messages
     -- 
-    local _, _, nomesg = string.find(body, globals.strMsgListNoMsgPat)
+    local nomesg = string.match(body, globals.strMsgListNoMsgPat)
     if (nomesg == nil) then
       return true, nil
     end
 
     -- Find only the HTML containing the message list
     --
-    local _, _, subBody = string.find(body, globals.strMsgListHTMLPattern)
+    local subBody = string.match(body, globals.strMsgListHTMLPattern)
     if (subBody == nil) then
       log.say("Yahoo Module needs to fix it's message list pattern matching.\n")
       return false, nil
@@ -1614,7 +1601,7 @@ function stat(pstate)
       -- Get the message id.  It's a series of a numbers followed by
       -- an underscore repeated.  
       --
-      _, _, msgid = string.find(msgid, globals.strMsgIDPattern) --'value="([%d-_]+)"')
+      msgid = string.match(msgid, globals.strMsgIDPattern) --'value="([%d-_]+)"')
       local uidl = string.gsub(msgid, "_[^_]-_[^_]-_", "_000_000_", 1);
       uidl = string.sub(uidl, 1, 60)
 
@@ -1629,8 +1616,8 @@ function stat(pstate)
       -- Convert the size from it's string (4k or 821b) to bytes
       -- First figure out the unit (KB or just B)
       --
-      local _, _, kbUnit = string.find(size, "([Kk])")
-      _, _, size = string.find(size, "([%d]+)[KkbB]")
+      local kbUnit = string.match(size, "([Kk])")
+      size = string.match(size, "([%d]+)[KkbB]")
       if not kbUnit then 
         size = math.max(tonumber(size), 0)
       else
@@ -1664,7 +1651,7 @@ function stat(pstate)
     -- Look in the body and see if there is a link for a previous page
     -- If so, change the URL
     --
-    local _, _, nextURL = string.find(body, globals.strMsgListPrevPagePattern)
+    local nextURL = string.match(body, globals.strMsgListPrevPagePattern)
     if nextURL ~= nil then
       cmdUrl = internalState.strMailServer .. nextURL
       return false
@@ -1689,7 +1676,7 @@ function stat(pstate)
 
     -- Is the session expired
     --
-    local _, _, strSessExpr = string.find(body, globals.strRetLoginSessionExpired)
+    local strSessExpr = string.match(body, globals.strRetLoginSessionExpired)
     if strSessExpr ~= nil then
       -- Invalidate the session
       --
@@ -1825,8 +1812,7 @@ function init(pstate)
 
   -- Soap
   --
-  require("soap/http")
-  require("soap/soap")
+  require("soap.http")
 
   -- Run a sanity check
   --
